@@ -484,7 +484,7 @@
 #include  "Zevhnv.h"
 
       integer:: inela
-      if( Move%proc /= "knoc" ) then
+      if( Move%proc /= "knoc"  .and.  Move%proc /= "dpair" ) then
          if( cTrack%inciflag == 1 ) then
             FirstInt = cTrack%pos
             FirstIntTrack =cTrack
