@@ -29,9 +29,13 @@ if  [ x"$modified" == "x" ]; then
    awk '$1=="#include" && index($2,"../main.f")>0 \
     { print ; system("cat $EPICSTOP/UserHook/INTINFOinclude"); next };  \
     {print}'  ephook.f > temptemp.f
-   mv temptemp.f ephook.f
-   echo "ok"
-   exit
+   cmp -s ephook.f temptemp.f
+   if [ $? -ne 0 ]; then
+       mv temptemp.f ephook.f
+       echo "ok-2"
+       exit
+   fi
+   rm -f temptemp.f 
 fi
 
 if [ x"$modified" == "x" ]; then
