@@ -1,4 +1,4 @@
-#define G95
+!  #define G95
 !  #define ABSOFT
       implicit none
 #include "Zprivate2.f"
