@@ -3,8 +3,8 @@
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepDraw.h"
-      record /Component/ comp  ! input. component
-      record /epPos/ p(*)     ! output. (x,y,z) to describe
+       type(Component)::  comp  ! input. component
+       type(epPos)::  p(*)     ! output. (x,y,z) to describe
                               !   a ccone in local coordnate.
                               ! (x,y,z)= gpsep is a separator
                               ! to be converted to a blank line
