@@ -1,37 +1,39 @@
       implicit none
 #include "Zmedia.h"
 #include "Zmass.h"
-c
-c          test Moller scattering cross-section
-c     At fixed electron energy, see the cross-section
-c     change as a function of cut off recoil electron
-c     energy.
-c 
-      record /epmedia/media
+!
+!          test Moller scattering cross-section
+!     At fixed electron energy, see the cross-section
+!     change as a function of cut off recoil electron
+!     energy.
+! 
+       type(epmedia):: media
       integer i, io, icon
       real*8 Ee, prob,  w, path, v, vm
       real*8 xm ,   g
-      character*80 file
+      character*130 file
+      character(len=8):: name
       real*8  epmollertx,  tx, txg, t0, beta2
 
       io = 10
       
       call  cerrorMsg(
-     * "Enter  electron energy(1. GeV),"//
-     * " minimum cutoff  recoil energy(200d-6 GeV)"//  
-     * " and file path('../../Data/Media/BGO')", 1)
+     * "Enter  electron energy(T.E .1 GeV),"//
+     * " minimum cutoff  recoil energy(100e-6 GeV)"//  
+     * " and media name(BGO)", 1)
       Ee = 1.
-      w = 200.0d-6
-      file = '../../Data/Media/BGO'
-      
-      read(*, *)  Ee, w, file
-      call cerrorMsg(file,  1)
+      w = 100.0e-6
+      name = "BGO"
 
+      
+      read(*, *)  Ee, w, name
+      call cerrorMsg(name,  1)
+      file = '$EPICSTOP/Data/Media/'//trim(name)
       call copenf(io, file, icon)
       call epReadTab(io, media)
       close(io)
       call epGetEffZA(media)
-      call epStern(w, media)
+      call epStern(media)
       g = Ee/masele
       t0 = Ee-masele
       beta2 = 1.-1/g/g
@@ -39,7 +41,7 @@ c
          vm =  w/t0
          call epmollerp(media, Ee, w,  prob, path)
          tx = epmollertx(g, vm)
-         txg = tx * masele/t0/beta2 * media.basearea*2.0
+         txg = tx * masele/t0/beta2 * media%basearea*2.0
          write(*,'(1p,4g12.4)')  w, prob, tx, txg
          w = w *10.**0.01
       enddo
