@@ -1,12 +1,12 @@
       implicit none
-c
-c         compute brems total xs.  prob/r.l, prob/(g/cm2), prob/cm , mb/atom
-c
+!
+!         compute brems total xs.  prob/r.l, prob/(g/cm2), prob/cm , mb/atom
+!
 #include "Zglobalc.h"
 #include "ZbasicCnst.h"
 #include "Zmedia.h"
 #include "Zmass.h"
-#include "ZBPgene.h"
+
 
       character*40  file
       integer io, result
@@ -34,13 +34,13 @@ c
 
          write(*,*) "#  'prob.  of Brems'"
          write(*,*) 
-     *   "#  'Ee(MeV)'  ' /r.l' '/(g/cm2)' '/cm' 'mb/atom'"
+     *   "#  'Ee(MeV)'  ' /r%l' '/(g/cm2)' '/cm' 'mb/atom'"
          Ee = 100.d-6
          do while ( Ee .lt. Eemax)   
             call epBrSampP(media, Ee, tprob, p)
             write(*, *) sngl(Ee*1000.d0), 
-     *       sngl(tprob), sngl(tprob/media.X0g),
-     *       sngl(tprob/media.X0), sngl(tprob/media.mbtoPX0)
+     *       sngl(tprob), sngl(tprob/media%X0g),
+     *       sngl(tprob/media%X0), sngl(tprob/media%mbtoPX0)
             Ee = Ee * 10.0d0**(0.05d0)
          enddo
       else
