@@ -60,7 +60,7 @@
       integer i
 
 
-      E = cnst%BrEe1H*1.00001d0
+      E = cnst%BrEe1H*1.00001d0  !  normally few x 0.1 GeV
 
       de = 10.**cnst%BrdEH
       do i = 1, size
@@ -119,7 +119,7 @@
       real*8 sqrtv
       real*8  epBrgenex
 
-      data eps/1.d-5/
+      data eps/1.d-8/
 
 
       de1 = 10.**cnst%BrdEH2
@@ -220,9 +220,9 @@
              u = us**aa
              upsi=u*tcb
              if(iu .le. 3) then
-                eps = 1.d-7
+                eps = 1.d-8
              else
-                 eps = 1.d-5
+                 eps = 1.d-8
              endif
              call kbchop(epBrgeneSolv, vl, vr, eps, v, j)
 !             call  kbinChop(epBrgeneSolv, vl, vr, guess,
