@@ -9,7 +9,7 @@
        type(epmedia):: media
 
       integer::icon, how
-      character(100)::file
+      character(100)::file   ! basic media file
       read(*, '(i2, a)')  how, file
       if( how < -1 .or. how >1 )  then
          write(0,*) ' how=',how, ' is wrong'
