@@ -4,11 +4,11 @@
 #include "Zmass.h"
 #include "ZBPgene.h"
 
-c
-c         epPrgenex. in mb
-c  This is the version for pair creation corrsponding to
-c  epBrgenex
-c     
+!
+!         epPrgenex. in mb
+!  This is the version for pair creation corrsponding to
+!  epBrgenex
+!     
       real*8 x  !  input Ee/Eg. 
 
 
@@ -26,7 +26,7 @@ c
 #include "Zmedia.h"
 #include "Zmass.h"
 #include "ZBPgene.h"
-      record /epmedia/ mediain  ! input media
+       type(epmedia)::  mediain  ! input media
       real(8),intent(in):: Egmein  ! Ee/me
 
       media = mediain
