@@ -34,7 +34,7 @@ media=$1; nevent=$2; E1=$3; E2=$4; step=$5;
 mkdir -p $work
 how=-1
 norm=1
-xmin=1.e-5
+xmin=1.e-8
 if [ $# -ge 6 ]; then
     LPMeffect=$6
 else
@@ -115,7 +115,7 @@ echo "Ncc=" $Ncc
 
   echo "Ek=${Ek}" > $work/gnuplot.com
   if [ $logx != 0 ]; then 
-      echo "set log x" >> $work/gnuplot.com
+      echo "set log xy" >> $work/gnuplot.com
   fi
   cat brems.gp | awk '{gsub(/WWW/, this); print}' this=$work  >> $work/gnuplot.com
 
