@@ -12,9 +12,20 @@ if [ $# -lt 2 ]; then
     To make all media in  $EPICSTOP/Data/BaseM/ target,
       ./ForManyMedia.sh /tmp  `(cd $EPICSTOP/Data/BaseM/; ls)`
      would work
+
+    Note: you must give 1st line of paramdata
 EOF
 exit
 fi
+echo "Next is 1st line of the paradata"
+head -n 1 paramdata
+echo "Is paramdata OK ?"
+echo "Enter y if so"
+read yesno
+if [ x$yesno != 'xy' ]; then
+    echo "bye bye"
+    exit
+fi
 dir=$1
 if [ ! -d $dir ]; then
     mkdir -p $dir
