@@ -13,9 +13,9 @@ fi
 source $EPICSTOP/Scrpt/setarch.sh
 
 echo $ARCH
-if [ ! -f mksmptab$ARCH ]; then
+#if [ ! -f mksmptab$ARCH.out ]; then
     make -f mkSmpTbl.mk
-fi
+#fi
 media=$1
 dir=$2
 echo $media | ./mksmptab$ARCH.out > $dir/$media
