@@ -35,7 +35,7 @@ program main
   call ciniSmpTab
   call csetSmpTblconst
 !   
-  write(*,'(f7.4, f7.4,a,a)')  &
+  write(*,'(f7.4, g12.4,a,a)')  &
   c1forHardScat,  maxHCSmfprl, ' c1forHardScat  maxHCSmfprl------- '
   call cmkSmpTab(DCSnega(j), TPXSnega(j), "e-")
 
