@@ -1,6 +1,7 @@
+!     expand config data.
 #include "ZepicsBD.h"
       implicit none
-c      
+!      
 #include  "ZepTrackv.h"
 #include  "Zcnfig.h"
 #include  "ZepManager.h"
@@ -8,7 +9,9 @@ c
       MediaDir(1) = '$EPICSTOP/Data/Media'
       write(0,*) ' Enter path to the config file'
       read(*,'(a)') dsn1
+      write(0,*) ' reading config'
       call eprcnf(dsn1)
+!  from level 1 to 1000 --> all data output-->6 stdout
       call epOutCnf(0, 1000, 6)
       end
 
