@@ -8,6 +8,7 @@
         data  Tcoef/5.d0/
         data  Tmin/1.d-3/
         data  EdepdEdx/.true./
+        data  HowQuench/1/
 	data  TargetElecBrems/0/
         data  TimeStruc/.false./
         data  Moliere/1/
@@ -40,6 +41,7 @@
         data  MagPair/0/
 	data  StoppingPw /1/
 	data  SrimEmax /0.09d0/
+	data  Zcorrec/.true./
 !        data  PhitsXs /0/
 !        data  JamXs /0/
         end
