@@ -1,7 +1,8 @@
-c            photo electric effect const.
+!            photo electric effect const.
        integer maxNoOfShells
        parameter(maxNoOfShells=20)
-       structure /photoE/
+       type photoE 
+       sequence
           real*8 b0        
           real*8 b1
           real*8 b2
@@ -16,5 +17,5 @@ c            photo electric effect const.
                         ! this is multiplied to old cross-section
 	  real*4 shellE(maxNoOfShells)  ! from v8.70
 	  integer noOfShells
-       end structure
+       end type photoE
   
