@@ -1,8 +1,9 @@
-c   #include "Zep3Vec.h" must preceed this.
+!   #include "Zep3Vec.h" must preceed this.
+#include "Zepcondc.h"
 #include "ZepMaxdef.h"
 #include "Zcnfig2.h"
 
-c           configuration of detector
+!           configuration of detector
 
         integer  maxCnArea   ! max size to memorize comp. numbers.
         parameter( maxCnArea = MAX_CN_AREA )
@@ -12,13 +13,12 @@ c           configuration of detector
 
 
         logical  Incused      ! #inc is used or not
-        logical  ExistID      ! if id=xxx,bb used somewhere--> t
 	integer ncmax         ! max components
         parameter ( ncmax = MAX_COMPONENT )
-c((((((((((
-c        integer MaxMatreska   ! max number of matreska
-c        parameter ( MaxMatreska = MAX_MATRESKA )
-c))))))))))
+!((((((((((
+!        integer MaxMatreska   ! max number of matreska
+!        parameter ( MaxMatreska = MAX_MATRESKA )
+!))))))))))
         integer ncmaxInSubD   ! max number of components in a sub det.
         parameter ( ncmaxInSubD = MAX_COMPONENT_IN_SUBD )
 
@@ -28,13 +28,13 @@ c))))))))))
         integer maxSubDRef    ! max number of sub detectors referrable
         parameter ( maxSubDRef = MAX_SUBD_REF )
 
-c        integer NPreDefName   ! number of predefined structures
-c        parameter ( NPreDefName = 5 )
+!        integer NPreDefName   ! number of predefined structures
+!        parameter ( NPreDefName = 5 )
   
-c        integer MaxNewStruc   ! max number of new structures constructable
-c        parameter ( MaxNewStruc = MAX_NEW_STRUC )
+!        integer MaxNewStruc   ! max number of new structures constructable
+!        parameter ( MaxNewStruc = MAX_NEW_STRUC )
 
-c           location of attribute characterizing a volume
+!           location of attribute characterizing a volume
         integer boxa, boxb, boxc  ! location for a,b,c edges of a box
         parameter (boxa =1, boxb = 2, boxc = 3)
 
@@ -73,53 +73,54 @@ c           location of attribute characterizing a volume
         parameter( EpsFor90 = EPS_FOR_90 )
         integer maxEq       !  max num. of #equate  efinable
         parameter ( maxEq = MAX_EQUATE )
-c  -------------------------------------------------------------------------
+!  -------------------------------------------------------------------------
 
-       structure /Component/
+       type Component 
+       sequence
          real*8 orgx, orgy, orgz,
      *          direc(9)
          real   offsetx, offsety, offsetz, MaxPathL
-	  character(MAX_STRUCCHR)::struc
-          character(8):: matter
+	  character(len=MAX_STRUCCHR):: struc
+          character(len=MAX_MEDIANAMELENG):: matter
 	 real  rhoc  ! rho calibration factor 
          real  EminG, EminE, RecoilE ! 
          real  LengGmin, LengChmin 
-c            LengGmin: If length to the boundary is > this (cm)
-c                      gamma is regarded absorbed safely.
-c                 fixed by Ex = min(10keV, EminG) and attenuation
-c                 length in the media.
-c   
-c            LengChmin: If length to the boundary is > this(cm)
-c                   charged ptcl is regarded absorbed safely.
-c                   (but, anti-ptcl, decayable ptcl is not).
-c                 fixed by Ex=min(10keV, EminE-mass) and
-c                  dE/dx of media at Ex. 
-c            
-c         integer  Nattributes,
-c     *            NMatreska,
-c     *            NContainer, vol,
+!            LengGmin: If length to the boundary is > this (cm)
+!                      gamma is regarded absorbed safely.
+!                 fixed by Ex = min(10keV, EminG) and attenuation
+!                 length in the media.
+!   
+!            LengChmin: If length to the boundary is > this(cm)
+!                   charged ptcl is regarded absorbed safely.
+!                   (but, anti-ptcl, decayable ptcl is not).
+!                 fixed by Ex=min(10keV, EminE-mass) and
+!                  dE/dx of media at Ex. 
+!            
+!         integer  Nattributes,
+!     *            NMatreska,
+!     *            NContainer, vol,
          integer  NMatreska, vol
 
-c               vol; vol+i is the i-th attribute of the component
-c                    in Volat
-c ((((((((((
-c     *            Contains(MaxMatreska),
-c     *            ContainsR(MaxMatreska),
+!               vol; vol+i is the i-th attribute of the component
+!                    in Volat
+! ((((((((((
+!     *            Contains(MaxMatreska),
+!     *            ContainsR(MaxMatreska),
          integer  Contains,
      *            ContainsR,
-c )))))))))))
-c (((((((((((
-c     *            PContained(MaxMatreska),
+! )))))))))))
+! (((((((((((
+!     *            PContained(MaxMatreska),
      *            PContained, cn, chno
-c            cn: component number assigned to this cmponent
-c )))))))))))
+!            cn: component number assigned to this cmponent
+! )))))))))))
 
 
        integer*2 NPContainer, CountIO,  CountDE, Modifier
-c  >>>>>>>>>>>>>>>>>>light        
+!  >>>>>>>>>>>>>>>>>>light        
          integer*2  LightCompNo
-c              LightCompNo; seq # given to light related comp
-c   <<<<<<<<<<<<<<<     
+!              LightCompNo; seq # given to light related comp
+!   <<<<<<<<<<<<<<<     
 
          integer*2 level
 
@@ -129,46 +130,52 @@ c   <<<<<<<<<<<<<<<
          integer*2 subdidx         ! ^^^^^^  
          integer*2 fsubdc      ! counter for no. of subdetectors
                                ! included in the last main boday.
-       end structure
+       end type Component
 
-       structure /Detector/
-          record /Component/cmp(ncmax)
+       type Detector 
+       sequence
+       type(Component):: cmp(ncmax)
           integer Cn2media(ncmax)
           integer nct
-c          integer  nbox, ncyl, npip, nprs, nsph,           
-          integer*2 nworld, nnew(MaxNewStruc)
-       end structure
+!          integer  nbox, ncyl, npip, nprs, nsph,           
+!!!!          integer*2 nworld, nnew(MaxNewStruc)
+!!!xxx          integer nworld, nnew(MaxNewStruc)
+          integer nworld
+       end type Detector
 
-       record /Component/SubdArea(ncmaxInSubD)
+       type(Component):: SubdArea(ncmaxInSubD)
 
-       structure /SubDetector/
+       type SubDetector 
+       sequence
           integer  loc
           integer nct
-c          integer  nbox, ncyl, npip, nprs, nsph,           
-          integer*2 nworld, nnew(MaxNewStruc)
-       end structure                 
+!          integer  nbox, ncyl, npip, nprs, nsph,           
+!!!!          integer*2 nworld, nnew(MaxNewStruc)
+!!!xxx
+          integer nworld
+       end type SubDetector
        integer  cumsubdloc
 
        real*8  PlusF, EqualF, MinusF
        integer NotGiven
        parameter( NotGiven = -9999999 )
        integer*2  EqualFshort
-       record /ep3Vec/ XYZthick(maxSubD)
+       type(ep3Vec)::  XYZthick(maxSubD)  ! --> use  real(8)
+       real(8)::ORGsubd(3,maxSubD)  
 
-c       ********************
-        record /Detector/Det
-        record /SubDetector/SubD(maxSubD)
-c       ********************
+!       ********************
+       type(Detector):: Det
+       type(SubDetector):: SubD(maxSubD)
+!       ********************
 
 
 
 	integer Nfield, NsubD, mode, SubDUsed, coment,
      *          PosInDet(maxSubDRef), SubDNumb(maxSubDRef),
-     *          SubDwithID(maxSubD+1),
      *          SumOffset(maxSubDRef), wrtcom, comcounter,
      *          comflag(maxcom), comloc 
 
-c
+!
 !   #if defined IBMAIX
 !        character*500  confdata
 !   #else
@@ -176,10 +183,9 @@ c
 !   #endif
         character*80 comarea(maxcom)
         character*24  Field(maxiattr), FieldAsItis(maxiattr)
-        character*131 idis
-        character*4 form
-c        character*8 SubDName(maxSubD),  PreDefName(NPreDefName)
-        character*16 SubDName(maxSubD)
+        character*4 form, OrgEqBy
+!        character*8 SubDName(maxSubD),  PreDefName(NPreDefName)
+        character(len=MAX_STRUCCHR) SubDName(maxSubD)  ! 16--> MAX_STRUCCHR v9.164
         integer SubDUsedList(maxSubD)			      
         character*16 EqName(maxEq)
         real*8  EqValue(maxEq)
@@ -188,23 +194,23 @@ c        character*8 SubDName(maxSubD),  PreDefName(NPreDefName)
         integer CnCounter   ! CnArea already used. 
         integer AttrCounter ! Volat already used.
         real*8  Volat(maxattr)
-c                next 2nd is v.8.10. to keep offset given as =0.45
+!                next 2nd is v.8.10. to keep offset given as =0.45
         real*4  VolatEq(maxattr)
         real*8  VTXx(maxvertex), VTXy(maxvertex), VTXz(maxvertex)
         integer NVTX       ! number of points in VTX*  
-c          above are given by calling epqenvlper or epenvlpAll
-c         if NVTX = 0, volume is assumed to be contained in a box
-c         
+!          above are given by calling epqenvlper or epenvlpAll
+!         if NVTX = 0, volume is assumed to be contained in a box
+!         
         common /Zcnfig/ Det, SubdArea,
-     1  SubD,  XYZthick, PlusF, EqualF, MinusF,
-     2  EqValue, Volat,  VTXx, VTXy, VTXz, VolatEq,
-     3  PosInDet, SubDNumb, SumOffset, subDwithID,  
+     1  SubD,  XYZthick, ORGsubd, PlusF, EqualF, MinusF, 
+     2  EqValue, Volat,  VTXx, VTXy, VTXz, VolatEq, 
+     3  PosInDet, SubDNumb, SumOffset,
      4  CnArea, comflag, CnCounter, AttrCounter, NVTX,
      5  coment, Nequates, cumsubdloc, SubDUsedList,
      6  Nfield, NsubD,  mode, SubDUsed, wrtcom, comcounter,
-     7  comloc, Incused, ExistID,  EqualFshort
+     7  comloc, Incused, 
+     *  EqualFshort
 
         common /Zcnfic/ confdata, comarea, Field, FieldAsItis,
-     *    SubDName, EqName, form, idis
-
-
+     *    SubDName, EqName, form, 
+     *   OrgEqBy
