@@ -14,7 +14,7 @@
          prob= 1.d-40
       else
          ale=log10(Ee)
-         call kintp3(media%tbl%BrTXL,
+         call kintp3(media%tbl%BrTXL(:,1),
      *   1, media%cnst%BremTXTL, media%cnst%BremLEemin,
      *   media%cnst%BremdETXL, ale, prob) 
       endif
