@@ -17,14 +17,14 @@
       elseif( Ee <= media%cnst%BrEemaxS) then
          Ek = Ee - masele
          ale=log10(Ek)
-
-         call kintp3(media%tbl%BrTXS,
+!     
+         call kintp3(media%tbl%BrTXS(:,1),
      *   1, media%cnst%BrTXTS, media%cnst%BrLEeminS,
      *   media%cnst%BrdETXS, ale, prob) 
       elseif(Ee <=  media%cnst%BrEemaxS2 ) then
          Ek = Ee - masele
          ale=log10(Ek)
-         call kintp3(media%tbl%BrTXS2,
+         call kintp3(media%tbl%BrTXS2(:,1),
      *   1, media%cnst%BrTXTS2, media%cnst%BrLEeminS2,
      *   media%cnst%BrdETXS2, ale, prob) 
       else
