@@ -1,7 +1,32 @@
+!     If next is defined,  use log table for eneries  very close to the
+!     threshold.
+!     If not defined, use log table for all energies at partial screening
+!     region. The latter will need ~5% more cpu time than the former
+!     (in the case of FirstKiss)       
+#define USELogTabOnlyLowE
+!            !#undef USELogTabOnlyLowE
       subroutine epPrLSampP(xmedia, Eg, prob)
       implicit none
 !     #include "Zmedia.h"
 #include "ZepTrackv.h"
+!
+#ifdef  USELogTabOnlyLowE      
+      real(8),parameter:: UseLogBelow=1.20d-3 ! below this, use log table
+      integer,parameter:: maxIdxLog=6 !make log table below this index
+!          see next table for index.      
+!    idx    Eg  Gev     prob/r.l (for  W)
+!     1  1.02300E-03  1.36858E-10
+!     2  1.22149E-03  6.69279E-04
+!     3  1.45848E-03  4.34835E-03
+!     4  1.74146E-03  1.21478E-02
+!     5  2.07935E-03  2.41705E-02
+!     6  2.48279E-03  4.01101E-02
+!     7  2.96451E-03  5.95280E-02
+!     8  3.53970E-03  8.19728E-02
+!     9  4.22648E-03  0.10703
+!     10 5.04652E-03  0.13431    
+!
+#endif      
       type(epmedia):: xmedia
       logical,save::first(Maxmedia)=.true.
       real*8 Eg
@@ -14,17 +39,24 @@
       logical,save::onlyonce=.true.
 
       if( onlyonce ) then
-         allocate( logtbl(mxPrTXL, NoOfMedia)) ! log table
+#ifdef  USELogTabOnlyLowE         
+         allocate( logtbl(maxIdxLog, NoOfMedia)) ! log table
+#else
+         allocate( logtbl(mxPrTXL, NoOfMedia)) ! log table for entire region
+#endif         
          onlyonce =.false.
       endif
       if( first(MediaNo))  then
-!          take log of the total crross-section
-         do i = 1, xmedia%cnst%PairTXTL
+!     take log of the total crross-section
+#ifdef  USELogTabOnlyLowE         
+         do i = 1, maxIdxLog
+#else
+         do i = 1, xmedia%cnst%PairTXTL         
+#endif                     
             logtbl(i,MediaNo)=log( xmedia%tbl%PrTXL(i) )
          enddo
          first(MediaNo) = .false.
       endif
-      
       if(Eg .lt. xmedia%cnst%PairEgmin) then
          prob= 1.d-40
       else
@@ -33,20 +65,34 @@
 !     but for very small Eg, prob < 10^-8 and sometimes it becomes
 !     ~  -10^-4 and leads to boundary error. This error can be
 !     aovided with ElowerBndPair = 1.2 MeV in epics file.
-!     This version is bit slower than the no-log version by few % or so
-!     but can be used ElowerBndPair = 1.022 MeV . if this is 1.2MeV
-!     the value becomes ~2% (fluctutaion is large, even 1000 events
-!     so this %tage is not sure). 
-!     !     call kintp3(logtbl,   call kintp3(media.tbl.PrTXL,
-!     call kintp3(logtbl,   call kintp3(media.tbl.PrTXL,
-         call kintp3(logtbl(1,MediaNo),
-!         call kintp3( media%tbl%PrTXL,
+!     This version is bit slower than the no-log version by ~7% or so
+!     but can be use ElowerBndPair = 1.022 MeV . if this is 1.2MeV
+!     the value becomes ~2%
+#ifdef  USELogTabOnlyLowE                  
+         if(Eg < UseLogBelow ) then
+               ! PairTXTL need not be maxIdxLog 
+            call kintp3(logtbl(1,MediaNo),
      *      1, xmedia%cnst%PairTXTL, xmedia%cnst%PairLEgmin,
      *      xmedia%cnst%PairdETXL, ale, prob) 
-         prob = exp(prob)
+            prob = exp(prob)
+         else
+            call kintp3( xmedia%tbl%PrTXL,
+     *      1, xmedia%cnst%PairTXTL, xmedia%cnst%PairLEgmin,
+     *      xmedia%cnst%PairdETXL, ale, prob) 
+         endif
+#else
+         call kintp3(logtbl(1,MediaNo),
+     *    1, xmedia%cnst%PairTXTL, xmedia%cnst%PairLEgmin,
+     *    xmedia%cnst%PairdETXL, ale, prob) 
+          prob = exp(prob)
+#endif         
 !!!!!!!!
-!         write(*,*) '#test ', MediaNo, Eg, prob
-!!!!!!!!!!
+!          write(*,*) '#test ', MediaNo, Eg, prob          
+!          if( prob  <= 0.0 ) then
+!             write(0,*)  ' prob =', prob, Eg
+!             stop
+!          endif
+!!!!!!!!!!!
       endif
       end
 !     ************
