@@ -53,6 +53,7 @@
       real*8  tbl(size,2), dummy
 
       character*160  msg
+      character(40)::almostdummy(2)
       integer i, nf
 
       read(io, '(a)') msg
@@ -65,7 +66,8 @@
       endif
       msg = ' '
       read(io,'(a)') msg
-      call kgetField(trim(msg), msg(80:), 2, nf)
+!      call kgetField(trim(msg), msg(80:), 2, nf)
+      call kgetField(trim(msg), almostdummy, 2, nf)
       
       do i = 1, size
          if(nf == 2 ) then
