@@ -1,10 +1,10 @@
       subroutine epLightGetBoxSurfN(a, b, c, x, y, z, surfn)
       use modepLightMaxDef
       implicit none
-c         get surface number of a given point (x,y,z)
-c         which  is assumed to be very close to one of the
-c         6 surface of a box 
-c
+!         get surface number of a given point (x,y,z)
+!         which  is assumed to be very close to one of the
+!         6 surface of a box 
+!
       real(8),intent(in):: a, b, c  !input.  3 edge lengths of a canonical box.
       real(8),intent(in):: x, y, z  !input    given point
       integer,intent(out):: surfn  ! output. surface number.  (1~6)
@@ -43,6 +43,8 @@ c
             write(0,*) ' warning: surface check i=',i, o(i)
             write(0,*) ' a, b,c=', a,b,c
             write(0,*) ' x, y,z=', x,y,z
+            write(0,*) ' for box'
+            write(0,*) '  '
          endif   
       endif
       end
