@@ -1,5 +1,5 @@
-c       photon counter at the exit of a "light" component
-c            or at the entrance of a  "light" component
+!       photon counter at the exit of a "light" component
+!            or at the entrance of a  "light" component
 
       subroutine epLightPC( info )
       use modepLightPty
@@ -16,22 +16,22 @@ c            or at the entrance of a  "light" component
       integer::surfN
 
       if(info <=0 ) then
-         call epLightGetSurfN(Cn, Move.boundary,  surfN)
+         call epLightGetSurfN(Cn, Move%boundary,  surfN)
       else
-         call epLightGetSurfN(Cn, Move.Track.pos,  surfN)
+         call epLightGetSurfN(Cn, Move%Track%pos,  surfN)
       endif
 
-      sub = Move.Track.p.subcode
+      sub = Move%Track%p%subcode
       if(info > 0 ) then
          call epLightAllocPC( entering )
          entering( cLcompNo )%pc(sub, surfN)  =
      *        entering( cLcompNo )%pc(sub, surfN)   + 
-     *              Move.Track.wgt
+     *              Move%Track%wgt
       else
          call epLightAllocPC( exiting )
          exiting( cLcompNo )%pc(sub, surfN)  =
      *   exiting( cLcompNo )%pc(sub, surfN)   + 
-     *        Move.Track.wgt
+     *        Move%Track%wgt
       endif
       end
 
@@ -40,39 +40,45 @@ c            or at the entrance of a  "light" component
 !        so  we make EntPC and ExtPC separately
       use modepLightCounter
       implicit none
+#include  "ZepMaxdef.h"
 #include  "ZepTrackv.h"
 
       type(photonc),intent(inout)::pcc(*)
-      character(len=16)::struc
+      character(len=MAX_STRUCCHR)::struc, basename  ! v9.164
 
 
-c///////////////
-      if( Move.Track.cn == 0 ) then
+!///////////////
+      if( Move%Track%cn == 0 ) then
          write(0,*)  ' MOve cn=0 iLightCounter '
       endif
-c/////////////
-      call epqstruc(Move.Track.cn, struc)
+!/////////////
+      call epqstruc(Move%Track%cn, struc)
+      call epGetBaseStrucName(struc, basename)
       if( .not. allocated( pcc(cLcompNo)%pc )) then
-         if(struc(1:3) == 'box') then
+         if( basename == 'box') then
             allocate(  pcc(cLcompNo)%pc(1:2,1:6)  )
             allocate(  pcc(cLcompNo)%pct(1:6) )
             pcc(cLcompNo)%pc(:,:) = 0.
-         elseif(struc(1:7) == 'octagon') then
+         elseif( basename == 'octagon') then
             allocate(  pcc(cLcompNo)%pc(1:2,1:10)  )
             allocate(  pcc(cLcompNo)%pct(1:10) )
             pcc(cLcompNo)%pc(:,:) = 0.
-         elseif( struc(1:3) == 'cyl') then 
+         elseif( basename == 'cyl') then 
             allocate( pcc(cLcompNo)%pc(1:2,1:3)  )
             allocate( pcc(cLcompNo)%pct(1:3) )
             pcc(cLcompNo)%pc(:,:) = 0.
-         elseif( struc(1:4) == 'ecyl') then 
+         elseif( basename == 'ecyl') then 
             allocate( pcc(cLcompNo)%pc(1:2,1:3)  )
             allocate( pcc(cLcompNo)%pct(1:3) )
             pcc(cLcompNo)%pc(:,:) =0.
-         elseif( struc(1:4) == 'pipe') then 
+         elseif( basename == 'pipe') then 
             allocate( pcc(cLcompNo)%pc(1:2,1:4)  )
             allocate( pcc(cLcompNo)%pct(1:4) )
             pcc(cLcompNo)%pc(:,:) = 0.
+         elseif( basename == 'prism') then
+            allocate(  pcc(cLcompNo)%pc(1:2,1:5)  )
+            allocate(  pcc(cLcompNo)%pct(1:5) )
+            pcc(cLcompNo)%pc(:,:) = 0.
          else
             write(0,*) ' structure =', struc, ' is ',
      *           ' not yet supported for light transport '
