@@ -1,12 +1,35 @@
-      subroutine epLightGetPipeSurfN(r1, r2, h,  x, y, z, surfn)
+      subroutine epLightGetPipeSurfN(comp, attr, aPos, surfn)
+!         get surface number of a given point (x,y,z)
+!         which  is assumed to be very close to one of the
+!         3 surfaces of a cyl
+      implicit none
+#include "Zep3Vec.h"
+#include "Zcnfig.h"
+#include "ZepPos.h"
+       type(Component)::  comp   !input component
+       type(epPos)::  aPos       ! input. track of which pos is examined
+      real(8),intent(in):: attr(3)  ! r1, r2, h
+      integer,intent(out)::surfn  ! output. surface number.  (1~4)
+                     !   1--> bottom, 2 top, 3 inner side  4 outer side
+
+       type(epPos)::  cpos
+
+      call epv2c_pipe(comp, aPos, cpos)
+      call epLightGetPipeSurfN0(attr(1), attr(2), attr(3), 
+     *  cpos%x, cpos%y, cpos%z,  surfn)
+
+      end subroutine epLightGetPipeSurfN
+
+
+      subroutine epLightGetPipeSurfN0(r1, r2, h, x, y, z, surfn)
       use modepLightMaxDef
       implicit none
 #include "ZepTrackv.h"
 
-c         get surface number of a given point (x,y,z)
-c         which  is assumed to be very close to one of the
-c         3 surfaces of a cyl
-c
+!         get surface number of a given point (x,y,z)
+!         which  is assumed to be very close to one of the
+!         3 surfaces of a cyl
+!
       real(8),intent(in)::r1, r2, h  !inner and outer radius and hight (cm)
       real(8),intent(in):: x, y, z  !  given point
       integer,intent(out)::surfn  ! output. surface number.  (1~4)
@@ -35,8 +58,8 @@ c
      *      CrossMode
             write(0,*) ' r1, r2, h =', r1,r2,  h
             write(0,*) ' x,y,z=', x, y, z
-            write(0,*) ' boundary=',Move.boundary
+            write(0,*) ' boundary=',Move%boundary
             write(0,*) ' closest surf. # is =', i, mind
          endif   
       endif
-      end
+      end   subroutine epLightGetPipeSurfN0
