@@ -10,7 +10,7 @@
       integer,save:: posinside
       real(8),parameter:: eps= 1.d-9
 !///////////
-!      logical,save:: mydebug=.false.
+!     logical,save:: mydebug=.false.
 !/////////////
 
       end module fpolygon
@@ -21,26 +21,27 @@
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepPos.h"
-c
-c         interface to read configuration data for "fpolygon"
-c
-      record /Component/ comp   ! output. to recieve the config data.
-c           read fpolygon data as 'new-*'
-c           fpolygon  has height and npoly vertex  attributes and the direction cosines
-c           of the 'x' and 'y'==> (1-6)
-c
+!
+!         interface to read configuration data for "fpolygon"
+!
+       type(Component)::  comp   ! output. to recieve the config data.
+!           read fpolygon data as 'new-*'
+!           fpolygon  has height and npoly vertex  attributes and the direction cosines
+!           of the 'x' and 'y'==> (1-6)
+!
       integer i,  j
-c             next is mandatory
+      character(len=MAX_STRUCCHR):: basename 
+!             next is mandatory
       call eprpst(comp, 0, 0, 1, 6)
       call epfpolygonCnst(comp)  ! this call, xmin etc  in Volat
                               ! are undefined.
-      j = comp.vol + 3
+      j = comp%vol + 3
       xmin=  Volat( j )
       xmax = Volat( j )
       ymin = Volat( j+1 )
       ymax = Volat( j+1)
 
-      j = comp.vol + 3
+      j = comp%vol + 3
       do i = 2, npoly*2, 2
          if(xmin > Volat( j+i) ) xmin = Volat(j+i)
          if(xmax < Volat( j+i) ) xmax = Volat(j+i)
@@ -52,13 +53,9 @@ c             next is mandatory
       Volat( j+1 ) = ymin
       Volat( j+2 ) = xmax
       Volat( j+3 ) = ymax
-
-      if( comp.struc == 'fpolygon' .or.
-     *    comp.struc == 'fpolygon_xy'     ) then
-      elseif( comp.struc == 'fpolygon_yz' ) then
-      elseif( comp.struc == 'fpolygon_zx' ) then
-      else
-         write(0,*) 'structure=',comp.struc, ' not usable'
+      call epGetBaseStrucName(comp%struc, basename)
+      if( basename /= 'fpolygon' ) then
+         write(0,*) 'structure=',comp%struc, ' not usable'
          stop
       endif
       end   subroutine eprfpolygon
@@ -68,23 +65,27 @@ c             next is mandatory
       implicit none
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
-c
-c         interface to read configuration data for "fpolygon"
-c
-      record /Component/ comp   ! output. to recieve the config data.
+!
+!         interface to read configuration data for "fpolygon"
+!
+       type(Component)::  comp   ! output. to recieve the config data.
       integer::j
-c           check some values
-      if( Compnum /= comp.cn ) then
-         npoly = Volat( comp.vol + 1)
-         height = Volat( comp.vol + 2)
-         Compnum = comp.cn
+!           check some values
+!      if( Compnum /= comp.cn ) then  ! this is dangerous.
+!                        since diff. comp. may get same cn.
+!                        at the time of config reading
+      if( Compnum /= comp%vol ) then   ! while comp.vol is uniq
+         npoly = Volat( comp%vol + 1)
+         height = Volat( comp%vol + 2)
+!         Compnum = comp.cn
+         Compnum = comp%vol
          if( npoly<=2 .or. height<=0 ) then
             write(0,*) ' npoly=',npoly, ' for fpolygon '
             write(0,*) ' height=', height
             write(0,*) ' some of above invalid'
             stop
          endif
-         j = comp.vol+ 3  + npoly*2 
+         j = comp%vol+ 3  + npoly*2 
          xmin = Volat( j ) 
          ymin = Volat( j+1 )
          xmax = Volat( j+2 ) 
@@ -101,17 +102,17 @@ c           check some values
 #include "ZepDirec.h"
 #include "Zepdebug.h"
 
-c
-c        find length to the boundary of 'comp' from 'pos'
-c        with direction cos 'dir'
-c     'pos' and 'dir' are given in this 'comp' local coordinate.
-c 
+!
+!        find length to the boundary of 'comp' from 'pos'
+!        with direction cos 'dir'
+!     'pos' and 'dir' are given in this 'comp' local coordinate.
+! 
  
 
-      record /Component/comp    ! input. you can extract volume parameters
+       type(Component):: comp    ! input. you can extract volume parameters
                           !            by Volat( comp.vol + 1), etc
-      record /epPos/ posl       ! input.  position.
-      record /epDirec/ dirl      ! input. direction cosinse
+       type(epPos)::  posl       ! input.  position.
+       type(epDirec)::  dirl      ! input. direction cosinse
 
       real(8):: el                !  output length cm from pos to the boundary
       integer:: icon              ! output 0: el obtained. pos    is inside
@@ -125,46 +126,46 @@ c
       call epv2c_fpolygon(comp, posl, cposl)
       call epv2cd_fpolygon(comp, dirl, cdirl)
 !//////////
-!      if( abs(cposl(1) -  1.8061953868) < 1.d-8 .and.
-!     *    abs(cdirl(1) + 0.170901811580583 ) < 1.d-8 ) then
-!         mydebug= .false.  ! 
+!      if( abs(cposl(1) - 22.6299991148469d0) < 1.d-8 .and.
+!     *    abs(cdirl(1) -0.716320230980483d0 ) < 1.d-8 ) then
+!         mydebug= .true.
 !      endif
 !////////////////
       call epbfpolygon0(comp, cposl, cdirl, el, icon)
       end subroutine epbfpolygon
 
-c      **********************************
+!      **********************************
       subroutine epsfpolygon(comp, pos, icon)
       use fpolygon
       implicit none
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepPos.h"
-c
-c           judge if a given 'pos' is inside 'comp'
-c         
-      record /Component/ comp !input component
-      record /epPos/ pos  ! input. position in  local coord.
+!
+!           judge if a given 'pos' is inside 'comp'
+!         
+       type(Component)::  comp !input component
+       type(epPos)::  pos  ! input. position in  local coord.
       integer icon  ! output. 0--> pos is inside
                     !         1-->        outside
-      record /epPos/ cpos
+       type(epPos)::  cpos
 
 
       call epv2c_fpolygon(comp, pos, cpos)
       call epsfpolygon0(comp, cpos, icon)
       end subroutine epsfpolygon
-c      **********************************
+!      **********************************
       subroutine epsfpolygon0(comp, pos, icon)
       use fpolygon
       implicit none
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepPos.h"
-c
-c           judge if a given 'pos' is inside 'comp'
-c         
-      record /Component/ comp !input component
-!      record /epPos/ pos  ! input. position in  local coord.
+!
+!           judge if a given 'pos' is inside 'comp'
+!         
+       type(Component)::  comp !input component
+!      record /epPos/ pos  ! input. position; canonical
       real(8),intent(in):: pos(3)
       integer,intent(out):: icon  ! output. 0--> pos is inside
                     !         1-->        outside
@@ -180,7 +181,7 @@ c
          icon = 1
          return
       else
-         j = comp.vol + 3
+         j = comp%vol + 3
         call kinout2(Volat(j),2, Volat(j+1),2,
      *    npoly, pos(1), pos(2), inside)
 !         call kinout(Volat(j),2, Volat(j+1),2,
@@ -201,47 +202,33 @@ c
       endif
       end subroutine epsfpolygon0
 
-c     **************************************
+!     **************************************
       subroutine epenvlpfpolygon(comp, org, abc)
       implicit none
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepPos.h"
-c
-c        give the envloping box of the component
-c
-      record /Component/ comp  ! input.   component.
-      record /epPos/ org       ! output.  origin of the enveloping box
+!
+!        give the envloping box of the component
+!
+       type(Component)::  comp  ! input.   component.
+       type(epPos)::  org       ! output.  origin of the enveloping box
                                !          in local coord. 
-      record /ep3Vec/ abc      ! output.  a,b,c of the box
+       type(ep3Vec)::  abc      ! output.  a,b,c of the box
 
       real(8):: temp, temp2
-      call  epenvlpfpolygon0(comp, org, abc)
-      if(comp.struc == 'fpolygon' ) then
-      elseif( comp.struc == 'fpolygon_xy' ) then
-      elseif( comp.struc == 'fpolygon_yz' ) then
-         temp = abc.x
-         temp2 = abc.y
-         abc = ep3Vec(abc.z, temp, temp2)
-      elseif( comp.struc == 'fpolygon_zx' ) then
-         temp = abc.x
-         temp2 = abc.y
-         abc = ep3Vec( temp2, abc.z, temp)
-      else
-         write(0,*) ' comp.struc=',comp.struc
-         write(0,*) ' not usable error '
-         stop
-      endif
+      call epenvlpfpolygon0(comp, org, abc)
+      call epc2v_fpolygon(comp, abc, abc)
       end subroutine epenvlpfpolygon
 
-c    *************************************
+!    *************************************
       subroutine epatlocfpolygon(comp, loc)
       use fpolygon
       implicit none
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 
-      record /Component/ comp ! input.
+       type(Component)::  comp ! input.
       integer loc(*)
  
       integer i
@@ -264,14 +251,14 @@ c    *************************************
 #include "ZepDirec.h"
 #include "Zepdebug.h"
 
-c
-c        find length to the boundary of 'comp' from 'pos'
-c        with direction cos 'dir'
-c     'pos' and 'dir' are given in this 'comp' local coordinate.
-c 
+!
+!        find length to the boundary of 'comp' from 'pos'
+!        with direction cos 'dir'
+!     'pos' and 'dir' are given in this 'comp' local coordinate.
+! 
  
 
-      record /Component/comp    ! input. you can extract volume parameters
+       type(Component):: comp    ! input. you can extract volume parameters
                           !            by Volat( comp.vol + 1), etc
       real(8),intent(in):: posl(3)     ! input.  position.
       real(8),intent(in):: dirl(3)     ! input. direction cosinse
@@ -300,7 +287,7 @@ c
          x = el * dirl(1) + posl(1)
          y = el * dirl(2) + posl(2)
          ! see if it is inside upper flat polygon
-         call kinout2(Volat(comp.vol+3),2,  Volat(comp.vol+4),2,
+         call kinout2(Volat(comp%vol+3),2,  Volat(comp%vol+4),2,
      *   npoly, x, y, inside)
 !         j = comp.vol+3
 !         call kinout(Volat(j),2, Volat(j+1),2,
@@ -324,7 +311,7 @@ c
          x = el * dirl(1) + posl(1)
          y = el * dirl(2) + posl(2)
          ! see if it is inside lower flat polygon
-         call kinout2(Volat(comp.vol+3),2,  Volat(comp.vol+4),2,
+         call kinout2(Volat(comp%vol+3),2,  Volat(comp%vol+4),2,
      *   npoly, x, y, inside)
 !         j = comp.vol+3
 !         call kinout(Volat(j),2, Volat(j+1),2,
@@ -373,7 +360,7 @@ c
             el = ( height-posl(3) ) /dirl(3)         
             x = el*dirl(1) + posl(1)
             y = el*dirl(2) + posl(2)
-            call kinout2(Volat(comp.vol+3),2,  Volat(comp.vol+4),2,
+            call kinout2(Volat(comp%vol+3),2,  Volat(comp%vol+4),2,
      *           npoly, x, y, inside)
 !            j = comp.vol+3
 !            call kinout(Volat(j),2, Volat(j+1),2,
@@ -387,7 +374,7 @@ c
             el = -posl(3)/dirl(3)
             x = el*dirl(1) + posl(1)
             y = el*dirl(2) + posl(2)
-            call kinout2(Volat(comp.vol+3),2, Volat(comp.vol+4),2,
+            call kinout2(Volat(comp%vol+3),2, Volat(comp%vol+4),2,
      *           npoly, x, y, inside)
 
 !            j = comp.vol+3
@@ -416,7 +403,7 @@ c
 
 !          seee side wall
  
-      record /Component/comp    ! input. you can extract volume parameters
+       type(Component):: comp    ! input. you can extract volume parameters
                           !            by Volat( comp.vol + 1), etc
       real(8),intent(in):: posl(3)     ! input.  position.
       real(8),intent(in):: dirl(3)     ! input. direction cosinse
@@ -427,36 +414,59 @@ c
                      !       -1: the line dose not cross the volume
  
       real(8)::p1(3), p2(3)
-      integer i, j, jcon
+      real(8)::p3(3), p4(3)
+      integer i, j, jcon, kcon
       real(8),parameter::eps2=2.d-5
 
-      j = comp.vol + 2
+      j = comp%vol + 2
       p2(1) = Volat(j+1)
       p2(2) = Volat(j+2)
       p2(3) = 0.d0
       do i = 1, npoly*2, 2
          p1(:) = p2(:) 
+!!!  for epxpLand4vp
+         p4(1:2) = p1(1:2)
+         p4(3) = height
+!!!
          if(i == npoly*2-1) then
             p2(1) = Volat(j+1)
             p2(2) = Volat(j+2)
             p2(3) = 0.
+!!!  for epxpLand4vp
+            p3(1:2)= p2(1:2)
+            p3(3) = height
+!!!
          else
             p2(1) = Volat(j+i+2)
             p2(2) = Volat(j+i+3)
             p2(3) = 0.
+
+!!!  for epxpLand4vp
+            p3(1:2) = p2(1:2)
+            p3(3) = height
+!!!
          endif
-         call kxplvsq(posl, dirl, p1, p2, height, el, jcon)
-         if(jcon == 0 ) then
+
+         call epxpLand4vp(p1, p2, p3, p4, posl,dirl,
+     *         el, kcon, jcon)
+
+!!!          near the boundary, next sometimes  fials
+!!!       call kxplvsq(posl, dirl, p1, p2, height, el, jcon)
+!//////////////
+!         if(mydebug) then
+!            write(0,*) 'after kxplvsq : H=', height, i
+!            write(0,*) 'posl=',posl(:)
+!            write(0,*) 'dirl=',dirl(:)
+!            write(0,*) 'p1=', p1(:)
+!            write(0,*) 'p2=', p2(:)
+!            write(0,*) ' jcon, el=',jcon, el
+!         endif
+!///////////////
+!!         if(jcon == 0 ) then
+         if( kcon <= 4 .and. el > 0.d0) then
             if(elmin > el ) then
                elmin = el
             endif
-         elseif( posinside == 0 ) then
-            if( abs(el) < eps2) then
-               el = abs(el)
-               if(elmin > el) then
-                  elmin = el
-               endif
-            endif
          endif
       enddo
       el = elmin
@@ -475,7 +485,8 @@ c
             ! the particle is outsied and no X-ing point
             ! When the incident is vertical, this apts to happen.
             !
-            posinside = 1
+!!!            posinside = 1
+
 !           if(mydebug) then
 !             write(0,*) 'posl =',posl(:)
 !             write(0,*) 'posl+dr=',posl(:)+1*dirl(:)
@@ -483,14 +494,18 @@ c
 !             write(0,*) 'comp# =',comp.cn
 !             write(0,*) ' name=',comp.struc
 !             write(0,*) ' posl is inside but no Xpoint'
+!             j = comp.vol + 1
+!             do i = 1, npoly*2, 2
+!                write(0,*) ' vertex ' 
+!                write(0,*)  i, Volat(j+i+1), Volat(j+i+2)
+!             enddo
 !             stop
 !           endif
-
          endif
          icon = -1
       endif
       end subroutine ep_fpolygon_side
-c     **************************************
+!     **************************************
       subroutine epenvlpfpolygon0(comp, org, abc)
       use fpolygon
       implicit none
@@ -498,22 +513,20 @@ c     **************************************
 #include "Zcnfig.h"
 #include "ZepPos.h"
 
-c
-c        give the envloping box of the component
-c
-      record /Component/ comp  ! input.   component.
-      record /epPos/ org       ! output.  origin of the enveloping box
+!
+!        give the envloping box of the component
+!
+       type(Component)::  comp  ! input.   component.
+       type(epPos)::  org       ! output.  origin of the enveloping box
                                !          in local coord. 
-      record /ep3Vec/ abc      ! output.  a,b,c of the box
+       type(ep3Vec)::  abc      ! output.  a,b,c of the box
 
-      integer:: base
-      base = comp.vol
 
-      org =  epPos(xmin, ymin, 0.d0)
+      call epfpolygonCnst(comp)  ! for safety 
 
-      abc.x =  xmax - xmin
-      abc.y =  ymax - ymin
-      abc.z =  height
+
+      org = epPos(xmin, ymin, 0.d0)
+      abc = ep3Vec( xmax - xmin,  ymax - ymin, height)
 
       NVTX = 0
       end subroutine epenvlpfpolygon0
@@ -524,21 +537,26 @@ c
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepPos.h"
-      record /Component/ comp  ! input.   component.
-      record /epPos/ posv     ! input
-      record /epPos/ posc     ! output
+       type(Component)::  comp  ! input.   component.
+       type(epPos)::  posv     ! input
+       type(epPos)::  posc     ! output can be posv
+
+       type(epPos)::  temp
 
       call epfpolygonCnst(comp)
-      if( comp.struc  == 'fpolygon' ) then
+      if( comp%struc  == 'fpolygon' .or. 
+     *    comp%struc  == 'fpolygon_w' ) then
          posc = posv
-      elseif( comp.struc  == 'fpolygon_xy' ) then
+      elseif( comp%struc(1:11)  == 'fpolygon_xy' ) then
          posc = posv
-      elseif( comp.struc == "fpolygon_yz" ) then
-         posc =epPos(posv.y, posv.z, posv.x)
-      elseif( comp.struc == "fpolygon_zx" ) then
-         posc = epPos( posv.z, posv.x, posv.y)
+      elseif( comp%struc(1:11) == "fpolygon_yz" ) then
+         temp =epPos(posv%y, posv%z, posv%x)
+         posc = temp
+      elseif( comp%struc(1:11) == "fpolygon_zx" ) then
+         temp = epPos( posv%z, posv%x, posv%y)
+         posc = temp 
       else
-         write(0,*) ' comp.struc=', comp.struc,
+         write(0,*) ' comp%struc=', comp%struc,
      *      ' to epbfpolygon is invalid'
          stop
       endif
@@ -553,24 +571,31 @@ c
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepPos.h"
-      record /Component/ comp  ! input.   component.
-      record /epPos/ posc     ! input
-      record /epPos/ posv     ! output
+       type(Component)::  comp  ! input.   component.
+       type(epPos)::  posc     ! input
+       type(epPos)::  posv     ! output (can be posc)
+
+       type(epPos)::  temp    !
 
       call epfpolygonCnst(comp)
-      if( comp.struc  == 'fpolygon' ) then
+      if( comp%struc  == 'fpolygon' .or.
+     *    comp%struc  == 'fpolygon_w'  ) then
          posv = posc
-      elseif( comp.struc  == 'fpolygon_xy' ) then
+      elseif( comp%struc(1:11)  == 'fpolygon_xy' ) then
          posv = posc
-      elseif( comp.struc == "fpolygon_yz" ) then
+      elseif( comp%struc(1:11) == "fpolygon_yz" ) then
 !                X:y   Y:z    Z:x
-         posv = epPos( posc.z, posc.x, posc.y)
-      elseif( comp.struc == "fpolygon_zx" ) then
+         temp = epPos( posc%z, posc%x, posc%y)
+!!         posc = temp !!!!!!!!!!!! aho
+         posv = temp
+      elseif( comp%struc(1:11) == "fpolygon_zx" ) then
 !         cpos = epPos( pos.z, pos.x, pos.y)
 !                  X:z    Y:x          Z:y
-         posv = epPos(posc.y, posc.z, posc.x)
+         temp = epPos(posc%y, posc%z, posc%x)
+!!         posc = temp  !!!!!!!!!! aho
+         posv = temp  
       else
-         write(0,*) ' comp.struc=', comp.struc,
+         write(0,*) ' comp%struc=', comp%struc,
      *      ' to epbfpolygon is invalid'
          stop
       endif
@@ -582,22 +607,27 @@ c
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepDirec.h"
-      record /Component/ comp  ! input.   component.
-      record /epDirec/ dirv     ! input
-      record /epDirec/ dirc     ! output
-
+       type(Component)::  comp  ! input.   component.
+       type(epDirec)::  dirv     ! input
+       type(epDirec)::  dirc     ! output  can be dirv
+ 
+       type(epDirec)::  temp
+     
       call epfpolygonCnst(comp)
 
-      if( comp.struc  == 'fpolygon' ) then
+      if( comp%struc  == 'fpolygon' .or.
+     *    comp%struc  == 'fpolygon_w' ) then
          dirc = dirv
-      elseif( comp.struc  == 'fpolygon_xy' ) then
+      elseif( comp%struc(1:11)  == 'fpolygon_xy' ) then
          dirc = dirv
-      elseif( comp.struc == "fpolygon_yz" ) then
-         dirc = epDirec(dirv.y, dirv.z, dirv.x)
-      elseif( comp.struc == "fpolygon_zx" ) then
-         dirc = epDirec(dirv.z, dirv.x, dirv.y)
+      elseif( comp%struc(1:11) == "fpolygon_yz" ) then
+         temp = epDirec(dirv%y, dirv%z, dirv%x)
+         dirc = temp
+      elseif( comp%struc(1:11) == "fpolygon_zx" ) then
+         temp = epDirec(dirv%z, dirv%x, dirv%y)
+         dirc = temp
       else
-         write(0,*) ' comp.struc=', comp.struc,
+         write(0,*) ' comp%struc=', comp%struc,
      *      ' to epbfpolygon is invalid'
          stop
       endif
@@ -610,24 +640,29 @@ c
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepDirec.h"
-      record /Component/ comp  ! input.   component.
-      record /epDirec/ dirc     ! input
-      record /epDirec/ dirv     ! output
+       type(Component)::  comp  ! input.   component.
+       type(epDirec)::  dirc     ! input
+       type(epDirec)::  dirv     ! output can be dirc
+
+       type(epDirec)::  temp
 
       call epfpolygonCnst(comp)
 !           (X,Y,Z)<---(x,y,z)
-      if( comp.struc  == 'fpolygon' ) then
+      if( comp%struc  == 'fpolygon' .or.
+     *    comp%struc  == 'fpolygon_w') then
          dirv = dirc
-      elseif( comp.struc  == 'fpolygon_xy' ) then
+      elseif( comp%struc(1:11)  == 'fpolygon_xy' ) then
          dirv = dirc
-      elseif( comp.struc == "fpolygon_yz" ) then
+      elseif( comp%struc(1:11) == "fpolygon_yz" ) then
 !         cdir = epDirec(dir.y, dir.z, dir.x)  X:y  Y:z  Z:x
-         dirv = epDirec(dirc.z, dirc.x, dirc.y) 
-      elseif( comp.struc  == 'fpolygon_zx' ) then
+         temp = epDirec(dirc%z, dirc%x, dirc%y) 
+         dirv = temp   
+      elseif( comp%struc(1:11)  == 'fpolygon_zx' ) then
 !         cdir = epDirec(dir.z, dir.x, dir.y)  X:z Y:x Z:y
-         dirv = epDirec(dirc.y, dirc.z, dirc.x) 
+         temp = epDirec(dirc%y, dirc%z, dirc%x) 
+         dirv = temp
       else
-         write(0,*) ' comp.struc=', comp.struc,
+         write(0,*) ' comp%struc=', comp%struc,
      *      ' to epbfpolygon is invalid'
          stop
       endif
