@@ -1,8 +1,3 @@
-!       honeycomb: when definining this, you have to
-!       give a tight bounding box (world) expressed by
-!       x,y,z range of
-!       (Xs, Xs+a), (Ys,Ys+b), (0, h)
-!
       module honeycomb
       integer,save::Compnum=-1000
       real(8),save::LL, LI, LS, h, W, Xs, a, Ys, b
@@ -174,24 +169,24 @@
 #include "Zglobalc.h"
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
-c
-c
-       record /Component/ comp  ! output. to recieve the config data.
+!
+!
+       type(Component)::  comp  ! output. to recieve the config data.
 
 
-c           9 volume attributes and the direction cosines
-c           (1~6)
-c
-c             next is mandatory
+!           9 volume attributes and the direction cosines
+!           (1~6)
+!
+!             next is mandatory
         call eprpst(comp, 9, 9, 1, 6)
-c
+!
         call  ep_honeycmCnst(comp)
 
         if(LI  <= 0. .or. LS <= 0 .or.  h <= 0. .or.
      *     W<=0. .or. Xs >= Sx+offx
      *    .or.  Xs < 0. .or. Ys < 0   ) then
            write(0, *)
-     *      comp.cn, '-th component: some of LL=', LL,
+     *      comp%cn, '-th component: some of LL=', LL,
      *    ' LI=',LI, ' LS=',LS, ' h=',h,
      *    ' W=', W,  ' Xs=',Xs, ' Ys=',Ys,
      *    ' for honeycomb  invalid'
@@ -199,12 +194,12 @@ c
         endif
         if( a <= 0 .or. b <= 0. ) then
            write(0, *)
-     *      comp.cn, '-th component: some of a=', a,
+     *      comp%cn, '-th component: some of a=', a,
      *    ' b=', b, ' for honeycomb  invalid'
            stop 98766
         endif
        end subroutine eprhoneycomb
-c   ***************************************
+!   ***************************************
       subroutine epbhoneycomb(comp, pos, dir, length, icon)
       use honeycomb
       implicit none
@@ -216,47 +211,91 @@ c   ***************************************
 #include "ZepDirec.h"
 #include "Zepdebug.h"
 
-c
-c    find length to the boundary of a honeycomb specfied by 
-c    'comp' from 'pos' with direction cos 'dir'
-c    'pos' and 'dir' are given in this 'comp' local coordinate.
-c     pos is may or may not be in side comp.
+!
+!    find length to the boundary of a honeycomb specfied by 
+!    'comp' from 'pos' with direction cos 'dir'
+!    'pos' and 'dir' are given in this 'comp' local coordinate.
+!     pos  may or may not be inside comp.
+! if pos is outside of B.B, and partilce can cross B.B, the
+! length is to the XP. So to get length to the honeycomb,
+! this may be called again.  (then, no xp may happen)
+!
+       type(Component):: comp    ! input.  honeycomb
 
-      record /Component/comp    ! input.  honeycomb
-
-      record /epPos/ pos        ! input.  position.
-      record /epDirec/ dir      ! input. direction cosinse
+       type(epPos)::  pos        ! input.  position.
+       type(epDirec)::  dir      ! input. direction cosinse
 
       real(8),intent(out):: length    !  length cm from pos to the boundary
-      integer,intent(out):: icon      ! t 0: length obtained. pos    is inside
-                     !        1:  //                        outside
-                     !       -1: the line dose not cross the volume
+      integer,intent(out):: icon  
+          !  0: length obtained. pos  is inside
+          !  1:  //                     outside ( xp is to the
+          !        B.B not to the honeycomb)
+          ! -1: the line dose not cross the volume
 
-      record /epPos/ cpos        ! input.  position.
-      record /epDirec/ cdir      ! input. direction cosinse
 
-      call ep_honeycmCnst(comp)
+       type(epPos)::  cpos        
+       type(epDirec)::  cdir      
 
-      if( comp.struc == "honeycomb" ) then
-         cpos = pos
-         cdir = dir 
-      elseif( comp.struc == "honeycomb_x" ) then
-         cpos = pos
-         cdir = dir
-      elseif( comp.struc == "honeycomb_y" ) then
-         cpos = epPos( pos.y, b-pos.x, pos.z)
-         cdir = epDirec( dir.y, -dir.x, dir.z)
-      elseif( comp.struc == "honeycomb_z" ) then
-         cpos = epPos( pos.z, b-pos.y, pos.x)
-         cdir = epDirec( dir.z, -dir.y, dir.x)
+      call epv2c_honeycomb(comp, pos, cpos) !  local to canonical
+      call epv2cd_honeycomb(comp, dir, cdir)  ! both pos and dir
+!        see if there is possibilty of xrossing.
+      call epbhoneyBB(comp, cpos, cdir, length,icon)
+      if( icon == 0 ) then  ! yes; so examine in detail
+         call epbhoneycm0(comp, cpos, cdir, length, icon)
       else
-         write(0,*) ' in epbhonycomb '
-         write(0,*) ' comp.struc=',comp.struc, 'unknown'
-         stop
+!          no xsing /or xing with B.B
       endif
-      call epbhoneycm0(comp, cpos, cdir, length, icon)
       end  subroutine epbhoneycomb
 
+      subroutine epbhoneyBB(comp, pos, dir, length, icon)
+!       see if the line starting from pos with dir can
+!       cross the bounding box of the honeycomb
+      use honeycomb
+      implicit none
+#include "Zglobalc.h"
+#include "ZepTrackp.h"
+#include "Zep3Vec.h"
+#include "Zcnfig.h"
+#include "ZepPos.h"
+#include "ZepDirec.h"
+#include "Zepdebug.h"
+
+       type(Component):: comp    ! input.  honeycomb
+     
+      real(8),intent(in):: pos(3)  !  position.  canonical
+      real(8),intent(in):: dir(3) !   direction cosinse. canonical
+      real(8),intent(out):: length ! length to the XP, if exists 
+      integer,intent(out):: icon  !   0 cross with the bb.
+                      !  -1   no  cross. so
+                      !   no possibility xsing honeycomb
+
+      logical:: kInsideBox  ! external func.
+      real(8)::  org(3), abc(3), spos(3)
+      call epenvlphoneycomb(comp, org, abc)
+! if config is:
+! honeycomb_zx  SCIN    0  0  0 /  7   5  6  -60 1 0.6  10  0.05 0\
+! .5 60  0.3 30
+!      org becomes: 0.5 0.3 0  (i.e, Xs, Ys, 0)
+      call epv2c_honeycomb(comp, abc, abc)
+!         abc becomes 60 30 10
+!        to see x.p existence,
+!        bounding box origin should be 0; so if Xs Ys is non zero
+!        we must shit particle position
+!      spos(1) = pos(1) - Xs
+!      spos(2) = pos(2) - Ys
+!      spos(3) = pos(3)  
+      spos(:) = pos(:) - org(:)   ! same as abvoe
+      if( kInsideBox(spos(1), spos(2), spos(3),
+     *   abc(1), abc(2), abc(3) ) )  then
+         icon = 0
+         length = 0.  ! dummy
+      else
+!           search xsing point with the b.b
+         call kxplbx(spos(1), spos(2), spos(3), dir(1), dir(2), 
+     *     dir(3), abc(1), abc(2), abc(3), length, icon)
+      endif
+      end  subroutine epbhoneyBB
+
 
       subroutine epbhoneycm0(comp, pos, dir, length, icon)
       use honeycomb
@@ -269,16 +308,16 @@ c     pos is may or may not be in side comp.
 #include "ZepDirec.h"
 #include "Zepdebug.h"
 
-c
-c    find length to the boundary of a honeycomb specfied by 
-c    'comp' from 'pos' with direction cos 'dir'
-c    'pos' and 'dir' are given in this 'comp' local coordinate.
-c     pos is may or may not be in side comp.
+!
+!    find length to the boundary of a honeycomb specfied by 
+!    'comp' from 'pos' with direction cos 'dir'
+!    'pos' and 'dir' are given in this 'comp' local coordinate.
+!     pos  may or may not be inside comp.
 
-      record /Component/comp    ! input.  honeycomb
+       type(Component):: comp    ! input.  honeycomb
 
-      record /epPos/ pos        ! input.  position.
-      record /epDirec/ dir      ! input. direction cosinse
+       type(epPos)::  pos        ! input.  position.
+       type(epDirec)::  dir      ! input. direction cosinse
 
       real(8),intent(out):: length    !  length cm from pos to the boundary
       integer,intent(out):: icon      ! t 0: length obtained. pos    is inside
@@ -295,22 +334,22 @@ c     pos is may or may not be in side comp.
 !         (since search is done without such boundary)
 !         if (xb, yb) below is outside, we must reset
 !         the boundary
-         xb = pos.x + length*dir.x
-         yb = pos.y + length*dir.y
+         xb = pos%x + length*dir%x
+         yb = pos%y + length*dir%y
          lengc = 0
          if(xb < Xs ) then
             lengc = lengc + 1
-            leng(lengc) = (Xs-pos.x)/dir.x  ! dir.x should not be 0
+            leng(lengc) = (Xs-pos%x)/dir%x  ! dir.x should not be 0
          elseif(xb > Xs+a) then
             lengc = lengc + 1
-            leng(lengc) = ((Xs+a)-pos.x)/dir.x
+            leng(lengc) = ((Xs+a)-pos%x)/dir%x
          endif
          if(yb < Ys ) then
             lengc = lengc + 1
-            leng(lengc) = (Ys-pos.y)/dir.y
+            leng(lengc) = (Ys-pos%y)/dir%y
          elseif(yb > Ys+b) then
             lengc = lengc + 1
-            leng(lengc) = (Ys+b-pos.y)/dir.y
+            leng(lengc) = (Ys+b-pos%y)/dir%y
          endif
          if(lengc > 0 ) then
             minlen = 1.d20
@@ -326,7 +365,7 @@ c     pos is may or may not be in side comp.
       endif
       end  subroutine epbhoneycm0
 
-c   ***************************************
+!   ***************************************
       subroutine epbhoneycm1(comp, pos, dir, length, icon)
       use honeycomb
       implicit none
@@ -338,29 +377,29 @@ c   ***************************************
 #include "ZepDirec.h"
 #include "Zepdebug.h"
 
-c
-c    find length to the boundary of a honeycomb specfied by 
-c    'comp' from 'pos' with direction cos 'dir'
-c    'pos' and 'dir' are given in this 'comp' local coordinate.
-c     pos is may or may not be in side comp.
+!
+!    find length to the boundary of a honeycomb specfied by 
+!    'comp' from 'pos' with direction cos 'dir'
+!    'pos' and 'dir' are given in this 'comp' local coordinate.
+!     pos  may or may not be inside comp.
 
-      record /Component/comp    ! input.  honeycomb
+       type(Component):: comp    ! input.  honeycomb
 
-      record /epPos/ pos        ! input.  position.
-      record /epDirec/ dir      ! input. direction cosinse
+       type(epPos)::  pos        ! input.  position.
+       type(epDirec)::  dir      ! input. direction cosinse
 
       real(8),intent(out):: length    !  length cm from pos to the boundary
-      integer,intent(out):: icon      ! t 0: length obtained. pos    is inside
+      integer,intent(out):: icon      !  0: length obtained. pos    is inside
                      !        1:  //                        outside
                      !       -1: the line dose not cross the volume
 
       real(8)::  el
-      record /epPos/ p1, p2, p3, p4
-      record /epPos/ OO, AA, BB, CC
-      record /epPos/ OOp, AAp, BBp, CCp
-      record /epPos/ xyz
-      record /epPos/ normal
-      record /epDirec/ dcos
+       type(epPos)::  p1, p2, p3, p4
+       type(epPos)::  OO, AA, BB, CC
+       type(epPos)::  OOp, AAp, BBp, CCp
+       type(epPos)::  xyz
+       type(epPos)::  normal
+       type(epDirec)::  dcos
 
       real(8):: x, y
 
@@ -374,23 +413,18 @@ c     pos is may or may not be in side comp.
 !          inpos is also set if inside
       call epshoneycm0(comp, pos, icon)   ! this should be cm0. 
 !          move to unit honeycomb coordinate.
-      x = pos.x - Xc
-      y = pos.y - Yc
-!/////////////
-!      write(*,'(a, 2i3, 1p,7g15.6)') 's ', 
-!     *          icon, inpos, pos.x, pos.y, pos.z,
-!     *          x, y, Xc, Yc
-!/////////////
+      x = pos%x - Xc
+      y = pos%y - Yc
 
       if(icon == 1 ) then
          ! pos is outside; see if it crosses top or bottom
          ! (prob. large)
          !      z =  pos.z + el*dir.z  = 0.
-         if( dir.z >0. ) then
+         if( dir%z >0. ) then
                !  we can assume pos.z >=0 and pos.z<=h
-            el = (h-pos.z)/dir.z
-            xb = x + el*dir.x
-            yb = y + el*dir.y
+            el = (h-pos%z)/dir%z
+            xb = x + el*dir%x
+            yb = y + el*dir%y
            ! see if xb,yb is in inner hexagon
             call ep_honeyin2(xb, yb,  kcon) 
             if( kcon == 0 ) then
@@ -398,10 +432,10 @@ c     pos is may or may not be in side comp.
                icon = -1
                return
             endif
-         elseif(dir.z < 0.) then
-            el = -pos.z/dir.z
-            xb = x + el*dir.x
-            yb = y + el*dir.y
+         elseif(dir%z < 0.) then
+            el = -pos%z/dir%z
+            xb = x + el*dir%x
+            yb = y + el*dir%y
            ! see if xb,yb is in inner hexagon
             call ep_honeyin2(xb, yb,  kcon) 
             if( kcon == 0 ) then
@@ -416,7 +450,7 @@ c     pos is may or may not be in side comp.
          !  No. 2 wall
          normal = epPos(0.d0, 1.d0, 0.d0)
          dd = Yl
-         xyz = epPos(x, y, pos.z)
+         xyz = epPos(x, y, pos%z)
 !           inner vertex  
          p1 = epPos(Xl, Yl, 0.d0)
          p2 = epPos(Xl, Yl, h)
@@ -424,14 +458,14 @@ c     pos is may or may not be in side comp.
          p4 = epPos(-Xl, Yl, 0.d0)
          call epxpLand4vp2(p1, p2, p3, p4,
      *       xyz, dir, normal, dd, el, kcon, jcon)
-         if(kcon .le. 4 .and. el >= 0.d0 ) then
-            length = el
 !///////////////////
-!            write(*,'(a,1p,3G12.4)') 'w2 ',
+!            write(0,'(a,i3,1p,4G12.4)') 'w2 kcon, el', kcon, el,
 !     *            el*dir.x+x+Xc,
 !     *            el*dir.y+y+Yc,
 !     *            el*dir.z+pos.z
 !///////////////////
+         if(kcon .le. 4 .and. el >  0.d0 ) then
+            length = el
             return
          endif
 
@@ -445,14 +479,14 @@ c     pos is may or may not be in side comp.
          p4 = epPos(-Xl, -Yl, 0.d0)
          call epxpLand4vp2(p1, p2, p3, p4,
      *       xyz, dir, normal, dd, el, kcon, jcon)
-         if(kcon .le. 4 .and. el >= 0.d0) then
-            length = el
 !///////////////////
-!            write(*,'(a,1p,3G12.4)') 'w5 ',
+!            write(0,'(a,i3,1p,4G12.4)') 'w5 kcon el',kcon, el,
 !     *            el*dir.x+x+Xc,
 !     *            el*dir.y+y+Yc,
 !     *            el*dir.z+pos.z
 !///////////////////
+         if(kcon .le. 4 .and. el > 0.d0) then
+            length = el
             return
          endif
 
@@ -467,14 +501,15 @@ c     pos is may or may not be in side comp.
          p4 = epPos(Xl, Yl, 0.d0)
          call epxpLand4vp2(p1, p2, p3, p4,
      *       xyz, dir, normal, dd, el, kcon, jcon)
-         if(kcon .le. 4 .and. el >=0.d0 ) then
-            length = el
 !///////////////
-!            write(*,'(a,1p,3G12.4)') 'w1 ',
+!            write(0,'(a,i2,1p,4G12.4)') 'w1 kcon, el',kcon, el,
 !     *            el*dir.x+x+Xc,
 !     *            el*dir.y+y+Yc,
 !     *            el*dir.z+pos.z
 !///////////////////
+
+         if(kcon .le. 4 .and. el > 0.d0 ) then
+            length = el
             return
          endif
 
@@ -489,14 +524,14 @@ c     pos is may or may not be in side comp.
          p4 = epPos(-Xl, -Yl, 0.d0)
          call epxpLand4vp2(p1, p2, p3, p4,
      *       xyz, dir, normal, dd, el, kcon, jcon)
-         if(kcon .le. 4 .and. el >= 0.d0) then
-            length = el
 !///////////////
-!            write(*,'(a,1p,3G12.4)') 'w4 ',
+!            write(0,'(a,i3,1p,4G12.4)') 'w4 kocn, el=',kcon,el,
 !     *            el*dir.x+x+Xc,
 !     *            el*dir.y+y+Yc,
 !     *            el*dir.z+pos.z
 !///////////////////
+         if(kcon .le. 4 .and. el >  0.d0) then
+            length = el
             return
          endif
 
@@ -513,14 +548,14 @@ c     pos is may or may not be in side comp.
          p4 = epPos(-Xl0, 0.d0, 0.d0)
          call epxpLand4vp2(p1, p2, p3, p4,
      *       xyz, dir, normal, dd, el, kcon, jcon)
-         if(kcon .le. 4 .and. el >= 0.d0) then
-            length = el
 !///////////////
-!            write(*,'(a,1p,3G12.4)') 'w3 ',
+!            write(0,'(a,i3,1p,4G12.4)') 'w3,kcon,el=',kcon, el,
 !     *            el*dir.x+x+Xc,
 !     *            el*dir.y+y+Yc,
 !     *            el*dir.z+pos.z
 !///////////////////
+         if(kcon .le. 4 .and. el > 0.d0) then
+            length = el
             return
          endif
 
@@ -535,14 +570,14 @@ c     pos is may or may not be in side comp.
          p4 = epPos(Xl0, 0.d0, 0.d0)
          call epxpLand4vp2(p1, p2, p3, p4,
      *       xyz, dir, normal, dd, el, kcon, jcon)
-         if(kcon .le. 4 .and. el >= 0.d0) then
-            length = el
 !///////////////
-!            write(*,'(a,1p,3G12.4)') 'w6 ',
+!            write(0,'(a,i3,1p,4G12.4)') 'w6 kcon,el= ',kcon, el,
 !     *            el*dir.x+x+Xc,
 !     *            el*dir.y+y+Yc,
 !     *            el*dir.z+pos.z
 !///////////////////
+         if(kcon .le. 4 .and. el > 0.d0) then
+            length = el
             return
          endif
          write(0,*) 'should not come here: inside epbhoneycm1'
@@ -554,12 +589,12 @@ c     pos is may or may not be in side comp.
          AAp = epPos(Xu, Yu, 0.d0)
          BBp = epPos(Xu, Yu, h)
          CCp = epPos(Xl, Yl, h)
-         xyz = epPos(x, y, pos.z)
+         xyz = epPos(x, y, pos%z)
          dcos = dir
          if(inpos == 2 .or. inpos == 5) then
             if(inpos == 5) then
-               xyz.y = -xyz.y
-               dcos.y = -dcos.y
+               xyz%y = -xyz%y
+               dcos%y = -dcos%y
             endif
             OO=epPos(-Xl, Yl, 0.d0)
             AA=epPos(-Xl, Yl, h)
@@ -570,69 +605,59 @@ c     pos is may or may not be in side comp.
             dd = Yl
             call epxpLand4vp2(OOp, CCp, AA, OO,
      *       xyz, dcos, normal, dd, el, kcon, jcon)
-            if(kcon .le. 4 .and. el >= 0.d0 ) then
+            if(kcon .le. 4 .and. el > 0.d0 ) then
                length = el
-!////////////////////////
-!               write(*,'(a, 1p,3g12.4)') 'ihw  current pos',
-!     *            pos.x, pos.y, pos.z
-!
-!               write(*, '(a,i3,1p,4g12.4)') 
-!     *          'ihw ',inpos, el,
-!     *            el*dir.x+pos.x,
-!     *            el*dir.y+pos.y,
-!     *            el*dir.z+pos.z
-!////////////////////////
                return
             endif
 !              outer horizontal wall
             dd = Yu
             call epxpLand4vp2(AAp, BBp, BB, CC,
      *       xyz, dcos, normal, dd, el, kcon, jcon)
-            if(kcon .le. 4 .and. el >= 0.d0 ) then
-               length = el
 !////////////////////////
-!               write(*, '(a,i3,1p,3g12.4)') 
+!               write(0, '(a,i3,1p,3g12.4)') 
 !     *          'ohw ',inpos, 
 !     *            el*dir.x+x+Xc,
 !     *            el*dir.y+y+Yc,
 !     *            el*dir.z+pos.z
 !////////////////////////
+            if(kcon .le. 4 .and. el > 0.d0 ) then
+               length = el
                return
             endif
 !              2 --> 1 / wall
             normal =epPos(-sint/(1.d0-cost)*sqrt((1.0+cost)/2),
      *              sqrt( (1.0+cost)/2.), 0.d0)
-            dd = Xl*normal.x + Yl*normal.y
+            dd = Xl*normal%x + Yl*normal%y
 
             call epxpLand4vp2(AAp, BBp, CCp, OOp,
      *       xyz, dcos, normal, dd, el, kcon, jcon)
-            if(kcon .le. 4 .and. el >= 0.d0) then
-               length = el
 !////////////////////////
-!               write(*, '(a,i3,1p,3g12.4)') 
+!               write(0, '(a,i3,1p,3g12.4)') 
 !     *          'hw21 ',inpos, 
 !     *            el*dir.x+x+Xc,
 !     *            el*dir.y+y+Yc,
 !     *            el*dir.z+pos.z
 !////////////////////////
+            if(kcon .le. 4 .and. el > 0.d0) then
+               length = el
                return
             endif
 !            2 --> 3 / wall
             normal =epPos(sint/(1.d0-cost)*sqrt((1.0+cost)/2),
      *              sqrt( (1.0+cost)/2.), 0.d0)
-            dd =-Xl*normal.x + Yl*normal.y
+            dd =-Xl*normal%x + Yl*normal%y
 
             call epxpLand4vp2(CC, BB, AA, OO,
      *       xyz, dcos, normal, dd, el, kcon, jcon)
-            if(kcon .le. 4 .and. el >= 0.d0) then
-               length = el
 !////////////////////////
-!               write(*, '(a,i3,1p,3g12.4)') 
+!               write(0, '(a,i3,1p,3g12.4)') 
 !     *          'hw23 ',inpos, 
 !     *            el*dir.x+x+Xc,
 !     *            el*dir.y+y+Yc,
 !     *            el*dir.z+pos.z
 !////////////////////////
+            if(kcon .le. 4 .and. el > 0.d0) then
+               length = el
                return
             endif
 !              horizontal bottom wall
@@ -641,15 +666,15 @@ c     pos is may or may not be in side comp.
 
             call epxpLand4vp2(AAp, CC, OO, OOp,
      *       xyz, dcos, normal, dd, el, kcon, jcon)
-            if(kcon .le. 4 .and. el >= 0.d0) then
-               length = el
 !////////////////////////
-!               write(*, '(a,i3,1p,3g12.4)') 
+!               write(0, '(a,i3,1p,3g12.4)') 
 !     *          'hb ',inpos, 
 !     *            el*dir.x+x+Xc,
 !     *            el*dir.y+y+Yc,
 !     *            el*dir.z+pos.z
 !////////////////////////
+            if(kcon .le. 4 .and. el > 0.d0) then
+               length = el
                return
             endif
 
@@ -658,15 +683,15 @@ c     pos is may or may not be in side comp.
             dd = h
             call epxpLand4vp2(BBp, BB, AA, CCp,
      *       xyz, dcos, normal, dd, el, kcon, jcon)
-            if(kcon .le. 4 .and. el >= 0.d0 ) then
-               length = el
 !////////////////////////
-!               write(*, '(a,i3,1p,3g12.4)') 
+!               write(0, '(a,i3,1p,3g12.4)') 
 !     *          'ht ',inpos, 
 !     *            el*dir.x+x+Xc,
 !     *            el*dir.y+y+Yc,
 !     *            el*dir.z+pos.z
 !////////////////////////
+            if(kcon .le. 4 .and. el > 0.d0 ) then
+               length = el
                return
             endif
          else
@@ -682,16 +707,16 @@ c     pos is may or may not be in side comp.
             if(inpos == 1) then
             elseif( inpos == 3 ) then
 !               mirror left right
-               xyz.x = - xyz.x
-               dcos.x  =  -dcos.x
+               xyz%x = - xyz%x
+               dcos%x  =  -dcos%x
             elseif( inpos == 4 ) then
-               xyz.x = - xyz.x
-               xyz.y = - xyz.y
-               dcos.x = - dcos.x
-               dcos.y = - dcos.y
+               xyz%x = - xyz%x
+               xyz%y = - xyz%y
+               dcos%x = - dcos%x
+               dcos%y = - dcos%y
             elseif( inpos == 6 ) then
-               xyz.y = - xyz.y
-               dcos.y = -dcos.y
+               xyz%y = - xyz%y
+               dcos%y = -dcos%y
             endif
 
             !    inner  wall by f1i
@@ -699,30 +724,30 @@ c     pos is may or may not be in side comp.
             dd = Xl*sint+ Yl*cost
             call epxpLand4vp2(OO, CC, CCp, OOp,
      *       xyz, dcos, normal, dd, el, kcon, jcon)
-            if(kcon .le. 4 .and. el >= 0.d0) then
-               length = el
 !////////////////////////
-!               write(*, '(a,i3,1p,4g12.4)') 
+!               write(0, '(a,i3,1p,4g12.4)') 
 !     *          'iw ',inpos, el,
 !     *            el*dir.x+x+Xc,
 !     *            el*dir.y+y+Yc,
 !     *            el*dir.z+pos.z
 !////////////////////////
+            if(kcon .le. 4 .and. el > 0.d0) then
+               length = el
                return
             endif
             !    outer  wall by f1o
             dd = Xu*sint+ Yu*cost
             call epxpLand4vp2(AA, BB, BBp, AAp,
      *       xyz, dcos, normal, dd, el, kcon, jcon)
-            if(kcon .le. 4 .and. el >= 0.d0) then
-               length = el
 !////////////////////////
-!               write(*, '(a,i3,1p,4g12.4)') 
+!               write(0, '(a,i3,1p,4g12.4)') 
 !     *          'ow ',inpos, el,
 !     *            el*dir.x+x+Xc,
 !     *            el*dir.y+y+Yc,
 !     *            el*dir.z+pos.z
 !////////////////////////
+            if(kcon .le. 4 .and. el > 0.d0) then
+               length = el
                return
             endif
 !             side wall on X axis
@@ -730,33 +755,34 @@ c     pos is may or may not be in side comp.
             dd = 0.
             call epxpLand4vp(OO, AA, BB, CC, xyz, dcos,
      *        el, kcon, jcon)
-            if(kcon .le. 4 .and. el >=0 ) then
-               length = el
 !////////////////////////
-!               write(*, '(a,i3,1p,4g12.4)') 
+!               write(0, '(a,i3,1p,4g12.4)') 
 !     *          'sw0 ',inpos, el,
 !     *            el*dir.x+x+Xc,
 !     *            el*dir.y+y+Yc,
 !     *            el*dir.z+pos.z
 !////////////////////////
+
+            if(kcon .le. 4 .and. el > 0 ) then
+               length = el
                return
             endif
 !            side wall between 1 and 2
             normal =epPos(-sint/(1.d0-cost)*sqrt((1.0+cost)/2),
      *              sqrt( (1.0+cost)/2.), 0.d0)
-            dd = Xl*normal.x + Yl*normal.y
+            dd = Xl*normal%x + Yl*normal%y
             
             call epxpLand4vp2(AAp, BBp,  CCp, OOp,
      *       xyz, dcos, normal, dd, el, kcon, jcon)
-            if(kcon <= 4  .and. el >= 0.d0) then
-               length = el
 !////////////////////////
-!               write(*, '(a,i3,1p,4g12.4)') 
+!               write(0, '(a,i3,1p,4g12.4)') 
 !     *          'sw12 ',inpos, el,
 !     *            el*dir.x+x+Xc,
 !     *            el*dir.y+y+Yc,
 !     *            el*dir.z+pos.z
 !////////////////////////
+            if(kcon <= 4  .and. el > 0.d0) then
+               length = el
                return
             endif
 
@@ -765,15 +791,15 @@ c     pos is may or may not be in side comp.
             dd = 0.
             call epxpLand4vp2(OO, AA, AAp, OOp,
      *       xyz, dcos, normal, dd, el, kcon, jcon)
-            if(kcon <= 4 .and. el >= 0.d0) then
-               length = el
 !////////////////////////
-!               write(*, '(a,i3,1p,4g12.4)') 
+!               write(0, '(a,i3,1p,4g12.4)') 
 !     *          'bot ',inpos, el,
 !     *            el*dir.x+x+Xc,
 !     *            el*dir.y+y+Yc,
 !     *            el*dir.z+pos.z
 !////////////////////////
+            if(kcon <= 4 .and. el > 0.d0) then
+               length = el
                return
             endif
 !            top wall
@@ -781,15 +807,15 @@ c     pos is may or may not be in side comp.
             dd = h
             call epxpLand4vp2(CC, BB, BBp, CCp,
      *       xyz, dcos, normal, dd, el, kcon, jcon)
-            if(kcon <= 4  .and. el >= 0.d0) then
-               length = el
 !////////////////////////
-!               write(*, '(a,i3,1p,4g12.4)') 
+!               write(0, '(a,i3,1p,4g12.4)') 
 !     *          'top ',inpos, el,
 !     *            el*dir.x+x+Xc,
 !     *            el*dir.y+y+Yc,
 !     *            el*dir.z+pos.z
 !////////////////////////
+            if(kcon <= 4  .and. el > 0.d0) then
+               length = el
                return
             endif
          endif
@@ -805,31 +831,18 @@ c     pos is may or may not be in side comp.
 #include "ZepDirec.h"
 #include "Zcnfig.h"
 #include "ZepPos.h"
-c
-c           judge if a given 'pos' is inside 'comp'
-c         
-      record /Component/ comp !input honeycomb component 
-      record /epPos/ pos  ! input. position in  local coord.
+!
+!           judge if a given 'pos' is inside 'comp'
+!         
+       type(Component)::  comp !input honeycomb component 
+       type(epPos)::  pos  ! input. position in  local coord.
       integer icon  ! output. 0--> pos is inside
                     !         1-->        outside
 
-      record /epPos/ cpos   
+       type(epPos)::  cpos   
 
-      call ep_honeycmCnst(comp)
 
-      if( comp.struc == "honeycomb" ) then
-         cpos = pos
-      elseif( comp.struc == "honeycomb_x" ) then
-         cpos = pos
-      elseif( comp.struc == "honeycomb_y" ) then
-         cpos = epPos( pos.y, b-pos.x, pos.z)
-      elseif( comp.struc == "honeycomb_z" ) then
-         cpos = epPos( pos.z, b-pos.y, pos.x)
-      else
-         write(0,*) ' in epbhonycomb '
-         write(0,*) ' comp.struc=',comp.struc, 'unknown'
-         stop
-      endif
+      call epv2c_honeycomb(comp, pos, cpos)
       call epshoneycm0(comp, cpos, icon)
       end      subroutine epshoneycomb
 
@@ -842,11 +855,11 @@ c
 #include "ZepDirec.h"
 #include "Zcnfig.h"
 #include "ZepPos.h"
-c
-c           judge if a given 'pos' is inside 'comp'
-c         
-      record /Component/ comp !input honeycomb component 
-      record /epPos/ pos  ! input. position in  local coord.
+!
+!           judge if a given 'pos' is inside 'comp'
+!         
+       type(Component)::  comp !input honeycomb component 
+       type(epPos)::  pos  ! input. position in  local coord.
       integer icon  ! output. 0--> pos is inside
                     !         1-->        outside
 
@@ -857,18 +870,18 @@ c
       call ep_honeycmCnst(comp)
 
       inpos = 0
-      if( pos.z < 0. .or.  pos.z > h) then
+      if( pos%z < 0. .or.  pos%z > h) then
          icon = 1
-      elseif( pos.x < Xs .or. pos.x > Xs + a ) then
+      elseif( pos%x < Xs .or. pos%x > Xs + a ) then
          icon = 1
-      elseif( pos.y < Ys .or. pos.y > Ys + b ) then
+      elseif( pos%y < Ys .or. pos%y > Ys + b ) then
          icon = 1
       else
-         call ephoneyxy2unit(pos.x, pos.y,  jcon)
+         call ephoneyxy2unit(pos%x, pos%y,  jcon)
 !                 pos.x,y is in a unit  honeycomb (honeycomb may not be
 !                    closed one) 
-         x = pos.x - Xc
-         y = pos.y - Yc
+         x = pos%x - Xc
+         y = pos%y - Yc
          call ep_honeyin(x, y,  icon)
       endif
       end subroutine epshoneycm0
@@ -957,7 +970,7 @@ c
       icon = 1
       end subroutine  ep_honeyin2
 
-c     **************************************
+!     **************************************
       subroutine epenvlphoneycomb(comp, org, abc)
       use honeycomb
       implicit none
@@ -965,29 +978,18 @@ c     **************************************
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepPos.h"
-c
-c        give the envloping box of the component
-c
-      record /Component/ comp  ! input.   component.
-      record /epPos/ org       ! output.  origin of the enveloping box
+!
+!        give the envloping box of the component
+!
+       type(Component)::  comp  ! input.   component.
+       type(epPos)::  org       ! output.  origin of the enveloping box
                                !          in local coord. 
-      record /ep3Vec/ abc      ! output.  a,b,c of the box
+       type(ep3Vec)::  abc      ! output.  a,b,c of the box
+
 
-      real(8)::temp
-c                                                                                                    
       call epenvlphoneycm0(comp, org, abc)
+      call epc2v_honeycomb(comp, abc, abc)
 
-      if( comp.struc == 'honeycomb_y') then
-c         temp = org.x
-c         org = epPos(org.y, temp, org.z)
-         temp = abc.x
-         abc = ep3Vec(abc.y, temp, abc.z)
-      elseif( comp.struc == 'honeycomb_z') then
-c         temp = org.x
-c         org = epPos(org.z, org.y, org.x)
-         temp = abc.x
-         abc = ep3Vec(abc.z, abc.y, temp)
-      endif
       end    subroutine epenvlphoneycomb
 
 
@@ -999,27 +1001,27 @@ c         org = epPos(org.z, org.y, org.x)
 #include "Zcnfig.h"
 #include "ZepPos.h"
 
-c
-c        give the envloping box of the component
-c
-      record /Component/ comp  ! input.   component.
-      record /epPos/ org       ! output.  origin of the enveloping box
+!
+!        give the envloping box of the component
+!
+       type(Component)::  comp  ! input.   component.
+       type(epPos)::  org       ! output.  origin of the enveloping box
                                !          in local coord. 
-      record /ep3Vec/ abc      ! output.  a,b,c of the box
+       type(ep3Vec)::  abc      ! output.  a,b,c of the box
 
 
 
       real*8  zmin, zmax
       integer n
-c
+!
       call ep_honeycmCnst(comp)
 
-      org.x = Xs
-      org.y = Ys
-      org.z = 0.
-      abc.x = a
-      abc.y = b
-      abc.z = h
+      org%x = Xs
+      org%y = Ys
+      org%z = 0.
+      abc%x = a
+      abc%y = b
+      abc%z = h
       NVTX = 0
       end  subroutine epenvlphoneycm0
 !     _____________________________ 
@@ -1032,17 +1034,17 @@ c
 #include "Zcnfig.h"
 #include "ZepPos.h"
 
-      record /Component/ comp  ! input.   component.
-      if(CompNum /= comp.cn ) then
-         LL = Volat( comp.vol + 1)
-         LI = Volat( comp.vol + 2)
-         Ls = Volat( comp.vol + 3)
-         h = Volat( comp.vol + 4)
-         W = Volat( comp.vol + 5)
-         Xs = Volat( comp.vol + 6)
-         a =  Volat( comp.vol + 7)
-         Ys = Volat( comp.vol + 8)
-         b = Volat( comp.vol + 9)
+       type(Component)::  comp  ! input.   component.
+      if(CompNum /= comp%vol ) then
+         LL = Volat( comp%vol + 1)
+         LI = Volat( comp%vol + 2)
+         Ls = Volat( comp%vol + 3)
+         h = Volat( comp%vol + 4)
+         W = Volat( comp%vol + 5)
+         Xs = Volat( comp%vol + 6)
+         a =  Volat( comp%vol + 7)
+         Ys = Volat( comp%vol + 8)
+         b = Volat( comp%vol + 9)
          if(LL < 0 ) then
             if(abs(LL) == 60.) then
                cost=0.5d0
@@ -1108,7 +1110,8 @@ c
 !         write(0,*) ' Yu, Yl, Xl=',Yu, Yl, Xl
 !         write(0,*) ' Xu, Xu0=', Xu, Xu0
 !c//////////////
-         Compnum = comp.cn
+!         Compnum = comp.cn
+         Compnum = comp%vol
       endif
 
       end subroutine ep_honeycmCnst
@@ -1209,7 +1212,7 @@ c
       implicit none
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
-      record /Component/ comp   ! input.
+       type(Component)::  comp   ! input.
       integer loc(*)
       integer i
       do i = 1, 9
@@ -1217,5 +1220,149 @@ c
       enddo
       end subroutine epatlochoneycomb
 
+!=============================
+      subroutine epv2c_honeycomb(comp, posv, posc)
+      use honeycomb
+      implicit none
+#include "Zep3Vec.h"
+#include "Zcnfig.h"
+#include "ZepPos.h"
+       type(Component)::  comp  ! input.   component. 
+       type(epPos)::  posv     ! input   
+       type(epPos)::  posc     ! output    can be posv
+
+       type(epPos)::  temp
+
+      call ep_honeycmCnst(comp)
+      if( comp%struc  == 'honeycomb' .or.
+     *    comp%struc  == 'honeycomb_w'  ) then
+         posc = posv
+      elseif( comp%struc(1:12)  == 'honeycomb_xy' ) then
+         posc = posv
+      elseif( comp%struc(1:12) == "honeycomb_yz" ) then
+         temp =epPos(posv%y, posv%z, posv%x)
+         posc = temp
+      elseif( comp%struc(1:12) == "honeycomb_zx" ) then
+         temp = epPos( posv%z, posv%x, posv%y)
+         posc = temp
+!      elseif( comp.struc == "honeycomb_x" ) then
+!         posc = posv
+!      elseif( comp.struc == "honeycomb_y" ) then
+!         posc = epPos( posv.y, b-posv.x, posv.z)
+!      elseif( comp.struc == "honeycomb_z" ) then
+!         posc = epPos( posv.z, b-posv.y, posv.x)
+      else
+         write(0,*) ' comp%struc=', comp%struc,
+     *      ' to epv2c_honeycomb is invalid'
+         stop
+      endif
+      end   subroutine epv2c_honeycomb
+
+      subroutine epc2v_honeycomb(comp, posc, posv)
+      use honeycomb
+      implicit none
+#include "Zep3Vec.h"
+#include "Zcnfig.h"
+#include "ZepPos.h"
+       type(Component)::  comp  ! input.   component.
+       type(epPos)::  posc     ! input 
+       type(epPos)::  posv     ! output can be posc
+
+       type(epPos)::  temp
+
+      call ep_honeycmCnst(comp)
+      if( comp%struc  == 'honeycomb' .or.
+     *    comp%struc  == 'honeycomb_w'  ) then
+         posv = posc
+      elseif( comp%struc(1:12)  == 'honeycomb_xy' ) then
+         posv = posc
+      elseif( comp%struc(1:12) == "honeycomb_yz" ) then
+!                yzx:  y<->x   z<->y  x<->z
+         temp = epPos( posc%z, posc%x, posc%y)
+         posv = temp
+      elseif( comp%struc(1:12) == "honeycomb_zx" ) then
+!            zxy 
+         temp= epPos(posc%y, posc%z, posc%x)
+         posv = temp
+      else
+         write(0,*) ' comp%struc=', comp%struc,
+     *      ' to epc2v_honeycomb is invalid'
+         stop
+      endif
+      end   subroutine epc2v_honeycomb
+
+      subroutine epv2cd_honeycomb(comp, dirv, dirc)
+      use honeycomb
+      implicit none
+#include "Zep3Vec.h"
+#include "Zcnfig.h"
+#include "ZepDirec.h"
+       type(Component)::  comp  ! input.   component.
+       type(epDirec)::  dirv     ! input
+       type(epDirec)::  dirc     ! output can be dirv
+
+       type(epDirec)::  temp
+
+      call ep_honeycmCnst(comp)
+      if( comp%struc  == 'honeycomb' .or.
+     *    comp%struc  == 'honeycomb_w'  ) then
+         dirc = dirv
+      elseif( comp%struc(1:12)  == 'honeycomb_xy' ) then
+         dirc = dirv
+      elseif( comp%struc(1:12) == "honeycomb_yz" ) then
+!          yzx
+         temp = epDirec(dirv%y, dirv%z, dirv%x)
+         dirc = temp
+      elseif( comp%struc(1:12) == "honeycomb_zx" ) then
+         temp = epDirec(dirv%z, dirv%x, dirv%y)
+         dirc = temp
+!      elseif( comp.struc == "honeycomb_x" ) then
+!         dirc = dirv
+!      elseif( comp.struc == "honeycomb_y" ) then
+!         dirc = epDirec( dirv.y, -dirv.x, dirv.z)
+!      elseif( comp.struc == "honeycomb_z" ) then
+!         dirc = epDirec( dirv.z, -dirv.y, dirv.x)
+      else
+         write(0,*) ' comp%struc=', comp%struc,
+     *      ' to epv2cd_honeycomb is invalid'
+         stop
+      endif
+      end subroutine epv2cd_honeycomb
+
+      subroutine epc2vd_honeycomb(comp, dirc, dirv)
+      use honeycomb
+      implicit none
+#include "Zep3Vec.h"
+#include "Zcnfig.h"
+#include "ZepDirec.h"
+       type(Component)::  comp  ! input.   component.
+       type(epDirec)::  dirc     ! input
+       type(epDirec)::  dirv     ! output can be dirc
+
+       type(epDirec)::  temp
+      call ep_honeycmCnst(comp)
+!     (X,Y,Z)<---(x,y,z)
+      if( comp%struc  == 'honeycomb' .or.
+     *    comp%struc  == 'honeycomb_w' ) then
+         dirv = dirc
+      elseif( comp%struc(1:12)  == 'honeycomb_xy' ) then
+         dirv = dirc
+      elseif( comp%struc(1:12) == "honeycomb_yz" ) then
+!         cdir = epDirec(dir.y, dir.z, dir.x)  X:y  Y:z  Z:x
+!                 yzx
+         temp = epDirec(dirc%z, dirc%x, dirc%y)
+         dirv = temp
+      elseif( comp%struc(1:12)  == 'honeycomb_zx' ) then
+!         cdir = epDirec(dir.z, dir.x, dir.y)  X:z Y:x Z:y 
+         temp = epDirec(dirc%y, dirc%z, dirc%x)
+         dirv = temp 
+      else
+         write(0,*) ' comp%struc=', comp%struc,
+     *      ' to epc2vd_honeycomb is invalid'
+         stop
+      endif
+      end   subroutine epc2vd_honeycomb
+
+
 
 
