@@ -1,12 +1,12 @@
       subroutine epxpLand4vp(p1, p2, p3, p4, a, b, l, icon, jcon)
       implicit none
 #include "ZepPos.h"
-c        get a crossing point of a half line with a plane formed
-c        by the 4 points on a plane. and judge if the x point 
-c        is inside of the "square" formed by p1,p2,p3,p4.
-      record /epPos/ p1,p2,p3,p4 ! input.  
-      record /epPos/ a  ! input.  starting point of the half line
-      record /epPos/ b  ! input.  direction cos of the line |b| =1
+!        get a crossing point of a half line with a plane formed
+!        by the 4 points on a plane. and judge if the x point 
+!        is inside of the "square" formed by p1,p2,p3,p4.
+       type(epPos)::  p1,p2,p3,p4 ! input.  
+       type(epPos)::  a  ! input.  starting point of the half line
+       type(epPos)::  b  ! input.  direction cos of the line |b| =1
       real*8  l         ! output. a+lb is the crossing point.
                         !        l may be negative
 
@@ -21,15 +21,14 @@ c        is inside of the "square" formed by p1,p2,p3,p4.
                     !         0: p is not on the vertex
                     !         i: p=pi (i=1~4)
 
-      record /epPos/ n, p
+       type(epPos)::  n, p
       real*8 k
-
       call ep3p2plane(p1, p2, p3, n, k)
       call epxpLandP(a, b, n, k, l, icon)
       if(icon .le. 2) then
-         p.x = a.x + b.x*l
-         p.y = a.y + b.y*l
-         p.z = a.z + b.z*l
+         p%x = a%x + b%x*l
+         p%y = a%y + b%y*l
+         p%z = a%z + b%z*l
          call episPin4(p1, p2, p3, p4, n, p, icon, jcon)
       else
          icon = 6
@@ -38,13 +37,13 @@ c        is inside of the "square" formed by p1,p2,p3,p4.
       subroutine epxpLand4vp2(p1, p2, p3, p4, a, b, n, k, l, icon, jcon)
       implicit none
 #include "ZepPos.h"
-c        get a crossing point of a half line with a plane 
-c        expressed by normal verctor and distance form origin to
-c        the plane. 
-      record /epPos/ p1, p2, p3, p4 ! input. 4 points forming a plane
-      record /epPos/ a  ! input.  starting point of the half line
-      record /epPos/ b  ! input.  direction cos of the line |b| =1
-      record /epPos/ n  ! input.  normal vector
+!        get a crossing point of a half line with a plane 
+!        expressed by normal verctor and distance form origin to
+!        the plane. 
+       type(epPos)::  p1, p2, p3, p4 ! input. 4 points forming a plane
+       type(epPos)::  a  ! input.  starting point of the half line
+       type(epPos)::  b  ! input.  direction cos of the line |b| =1
+       type(epPos)::  n  ! input.  normal vector
       real*8 k          ! input. scaler product of n and any
                         ! point on the plane.  (normally distance
                         ! from the origin to the plane
@@ -62,13 +61,13 @@ c        the plane.
                     !         0: p is not on the vertex
                     !         i: p=pi (i=1~4)
 
-      record /epPos/ p
+       type(epPos)::  p
 
       call epxpLandP(a, b, n, k, l, icon)
       if(icon .le. 2) then
-         p.x = a.x + b.x*l
-         p.y = a.y + b.y*l
-         p.z = a.z + b.z*l
+         p%x = a%x + b%x*l
+         p%y = a%y + b%y*l
+         p%z = a%z + b%z*l
          call episPin4(p1, p2, p3, p4, n, p, icon, jcon)
       else
          icon = 6
@@ -77,12 +76,12 @@ c        the plane.
       subroutine epxpLand3vp(p1, p2, p3, a, b, l, icon, jcon)
       implicit none
 #include "ZepPos.h"
-c        get a crossing point of a half line with a plane formed
-c        by the 3 points. and judge if the x point 
-c        is inside of the "triangle" formed by p1,p2,p3
-      record /epPos/ p1,p2,p3 ! input.  
-      record /epPos/ a  ! input.  starting point of the half line
-      record /epPos/ b  ! input.  direction cos of the line |b| =1
+!        get a crossing point of a half line with a plane formed
+!        by the 3 points. and judge if the x point 
+!        is inside of the "triangle" formed by p1,p2,p3
+       type(epPos)::  p1,p2,p3 ! input.  
+       type(epPos)::  a  ! input.  starting point of the half line
+       type(epPos)::  b  ! input.  direction cos of the line |b| =1
       real*8  l         ! output. a+lb is the crossing point.  l  >=0
                         !        
 
@@ -96,44 +95,44 @@ c        is inside of the "triangle" formed by p1,p2,p3
                     !         0: p is not on the vertex
                     !         i: p=pi (i=1~3)
 
-      record /epPos/ n, p
+       type(epPos)::  n, p
       real*8 k
 
       call ep3p2plane(p1, p2, p3, n, k)
       call epxpLandP(a, b, n, k, l, icon)
       if(icon .le. 2) then
-         p.x = a.x + b.x*l
-         p.y = a.y + b.y*l
-         p.z = a.z + b.z*l
+         p%x = a%x + b%x*l
+         p%y = a%y + b%y*l
+         p%z = a%z + b%z*l
          call episPin3(p1, p2, p3, n, p, icon, jcon)
-c
-c      integer icon  ! output. 0: p is inside of the triangle formed by p1,2,3.
-c                    !         1: p is on the line, p1-p2.
-c                    !         2: p is on the p2-p3  line
-c                    !         3: p is on the p3-p1 line. 
-c                    !         4: p is outside of the triangle.
-c     integer jcon  ! output. has meaning only if icon =1~3.
-c                    !         0--> the point is not on the vertex
-c                    !         1--> p = p1
-c                    !         2--> p = p2
-c                    !         3--> p = p3 
-c
+!
+!      integer icon  ! output. 0: p is inside of the triangle formed by p1,2,3.
+!                    !         1: p is on the line, p1-p2.
+!                    !         2: p is on the p2-p3  line
+!                    !         3: p is on the p3-p1 line. 
+!                    !         4: p is outside of the triangle.
+!     integer jcon  ! output. has meaning only if icon =1~3.
+!                    !         0--> the point is not on the vertex
+!                    !         1--> p = p1
+!                    !         2--> p = p2
+!                    !         3--> p = p3 
+!
       else
          icon = 5
       endif
       end
       subroutine epxpLand3vpB(p1, p2, p3, a, b, l, towhich, icon)
-c/////////////
-c      use sqTccl,only:check 
-c///////////
+!/////////////
+!      use sqTccl,only:check 
+!///////////
       implicit none
 #include "ZepPos.h"
-c        get a crossing point of a half line with a plane formed
-c        by the 3 points. and judge if the x point 
-c        is inside of the "triangle" formed by p1,p2,p3
-      record /epPos/ p1,p2,p3 ! input.  
-      record /epPos/ a  ! input.  starting point of the half line
-      record /epPos/ b  ! input.  direction cos of the line |b| =1
+!        get a crossing point of a half line with a plane formed
+!        by the 3 points. and judge if the x point 
+!        is inside of the "triangle" formed by p1,p2,p3
+       type(epPos)::  p1,p2,p3 ! input.  
+       type(epPos)::  a  ! input.  starting point of the half line
+       type(epPos)::  b  ! input.  direction cos of the line |b| =1
       real(8),intent(out):: l         ! output. a+lb is the crossing point.  l  >=0
                         !        
       real(8),intent(out):: towhich  ! scaler proc. of plane's  normal vecter  and the b
@@ -147,41 +146,41 @@ c        is inside of the "triangle" formed by p1,p2,p3
                     !         4: p is outside of the "trianble"
                     !         5: line is parallel to the plane
 
-      record /epPos/ n, p
+       type(epPos)::  n, p
       real*8 k
 
       integer::jcon 
 
       call ep3p2plane(p1, p2, p3, n, k)
       call epxpLandP(a, b, n, k, l, icon)
-c///////////////
-c      if(check == 1 ) then
-c         write(0,*) ' n, k=', n, k
-c         write(0,*) ' landP l,icon =',l, icon
-c      endif
-c/////////////
+!///////////////
+!      if(check == 1 ) then
+!         write(0,*) ' n, k=', n, k
+!         write(0,*) ' landP l,icon =',l, icon
+!      endif
+!/////////////
       if(icon <= 2) then
-         p.x = a.x + b.x*l
-         p.y = a.y + b.y*l
-         p.z = a.z + b.z*l
+         p%x = a%x + b%x*l
+         p%y = a%y + b%y*l
+         p%z = a%z + b%z*l
          call episPin3(p1, p2, p3, n, p, icon, jcon)
-c///////////
-c         if(check == 1 ) then
-c            write(0,*) 'xp =',p
-c            write(0,*) 'Pin3 icon, jcon =', icon, jcon
-c         endif
-c////////////
-c
-c      integer icon  ! output. 0: p is inside of the triangle formed by p1,2,3.
-c                    !         1: p is on the line, p1-p2.
-c                    !         2: p is on the p2-p3  line
-c                    !         3: p is on the p3-p1 line. 
-c                    !         4: p is outside of the triangle.
-c     integer jcon  ! output. has meaning only if icon =1~3.
-c                    !         0--> the point is not on the vertex
-c                    !         1--> p = p1
-c                    !         2--> p = p2
-c                    !         3--> p = p3 
+!///////////
+!         if(check == 1 ) then
+!            write(0,*) 'xp =',p
+!            write(0,*) 'Pin3 icon, jcon =', icon, jcon
+!         endif
+!////////////
+!
+!      integer icon  ! output. 0: p is inside of the triangle formed by p1,2,3.
+!                    !         1: p is on the line, p1-p2.
+!                    !         2: p is on the p2-p3  line
+!                    !         3: p is on the p3-p1 line. 
+!                    !         4: p is outside of the triangle.
+!     integer jcon  ! output. has meaning only if icon =1~3.
+!                    !         0--> the point is not on the vertex
+!                    !         1--> p = p1
+!                    !         2--> p = p2
+!                    !         3--> p = p3 
          if( icon <= 3 ) then
             call epscalerProd(n, b, towhich)
          else
@@ -195,10 +194,10 @@ c                    !         3--> p = p3
       subroutine epxpLandP(a, b, n, k, l, icon)
       implicit none
 #include "ZepPos.h"
-c        get a crossing point of a half line with a given plane.
-      record /epPos/ a  ! input.  starting point of the half line
-      record /epPos/ b  ! input.  direction cos of the line |b| =1
-      record /epPos/ n  ! input   normal vector of the plane 
+!        get a crossing point of a half line with a given plane.
+       type(epPos)::  a  ! input.  starting point of the half line
+       type(epPos)::  b  ! input.  direction cos of the line |b| =1
+       type(epPos)::  n  ! input   normal vector of the plane 
       real*8  k         ! input.  n.x=k where x is any point on the plane
       real*8  l         ! output. a+lb is the crossing point.  
       integer icon      ! output. 0: crossing point obtained. (l>=0)
@@ -210,7 +209,7 @@ c        get a crossing point of a half line with a given plane.
       real*8 na, nb
       real*8 temp, eps
       data eps/1.d-8/
-      
+
       call epscalerProd(n, a, na)
       call epscalerProd(n, b, nb)
       temp = k - na
@@ -234,11 +233,11 @@ c        get a crossing point of a half line with a given plane.
       subroutine episPin3(p1, p2, p3, n, p, icon, jcon)
       implicit none
 #include "ZepPos.h"
-      record /epPos/ p1 ! input.  p1,p2,p3 are  non 
-      record /epPos/ p2 ! input. colinear points
-      record /epPos/ p3 ! input. to form a plane
-      record /epPos/ n  ! input. normal vector of the plane
-      record /epPos/ p  ! input given point which is on the plane fomred by
+       type(epPos)::  p1 ! input.  p1,p2,p3 are  non 
+       type(epPos)::  p2 ! input. colinear points
+       type(epPos)::  p3 ! input. to form a plane
+       type(epPos)::  n  ! input. normal vector of the plane
+       type(epPos)::  p  ! input given point which is on the plane fomred by
                         !  three points p1, p2, p3
 
       integer icon  ! output. 0: p is inside of the triangle formed by p1,2,3.
@@ -258,37 +257,37 @@ c        get a crossing point of a half line with a given plane.
       fxy(a1, b1, a2, b2, u, v) = (v-b1)*(a2-a1) - (u -a1)*(b2-b1)
       
 
-      nmax = max(abs(n.x), abs(n.y), abs(n.z))
-      if(nmax .eq. abs(n.x)) then
-c             use projection on to y-z plane
-         x1 = p1.y
-         y1 = p1.z
-         x2 = p2.y
-         y2 = p2.z
-         x3 = p3.y
-         y3 = p3.z
-         x = p.y
-         y = p.z
-      elseif(nmax .eq. abs(n.y)) then
-c            use projection on to x-z plane
-         x1 = p1.x
-         y1 = p1.z
-         x2 = p2.x
-         y2 = p2.z
-         x3 = p3.x
-         y3 = p3.z
-         x = p.x
-         y = p.z
+      nmax = max(abs(n%x), abs(n%y), abs(n%z))
+      if(nmax .eq. abs(n%x)) then
+!             use projection on to y-z plane
+         x1 = p1%y
+         y1 = p1%z
+         x2 = p2%y
+         y2 = p2%z
+         x3 = p3%y
+         y3 = p3%z
+         x = p%y
+         y = p%z
+      elseif(nmax .eq. abs(n%y)) then
+!            use projection on to x-z plane
+         x1 = p1%x
+         y1 = p1%z
+         x2 = p2%x
+         y2 = p2%z
+         x3 = p3%x
+         y3 = p3%z
+         x = p%x
+         y = p%z
       else
-c             use projection on to x-y plane
-         x1  =p1.x
-         y1 = p1.y
-         x2  =p2.x
-         y2 = p2.y
-         x3  =p3.x
-         y3 = p3.y
-         x  =p.x
-         y = p.y
+!             use projection on to x-y plane
+         x1  =p1%x
+         y1 = p1%y
+         x2  =p2%x
+         y2 = p2%y
+         x3  =p3%x
+         y3 = p3%y
+         x  =p%x
+         y = p%y
       endif
 
       p12 = fxy( x1, y1, x2, y2, x, y)
@@ -319,7 +318,7 @@ c             use projection on to x-y plane
                   icon = 4
                endif
             else
-c                 p23 = 0
+!                 p23 = 0
                if( (x .ge. min(x2,x3) .and. x .le. max(x2,x3))
      *             .and.
      *          (y .ge. min(y2, y3) .and. y .le. max(y2, y3))) then
@@ -337,7 +336,7 @@ c                 p23 = 0
          icon = 4
          goto 100
       elseif(temp .eq. 0.) then
-c            p31 should be 0         
+!            p31 should be 0         
          icon =3
          if( (x .ge. min(x1,x3) .and. x .le. max(x1,x3))
      *             .and.
@@ -360,12 +359,12 @@ c            p31 should be 0
       subroutine episPin4(p1, p2, p3, p4, n, p, icon, jcon)
       implicit none
 #include "ZepPos.h"
-      record /epPos/ p1 ! input.  p1,p2,p3,p4 form a "square" plane.
-      record /epPos/ p2 ! input.  any 3 of which are not colinear
-      record /epPos/ p3 ! input.  "square" may be skewed
-      record /epPos/ p4 ! input.  2 of them may be the same.
-      record /epPos/ n  ! input. normal vector of the plane
-      record /epPos/ p  ! input given point which is on the plane fomred by
+       type(epPos)::  p1 ! input.  p1,p2,p3,p4 form a "square" plane.
+       type(epPos)::  p2 ! input.  any 3 of which are not colinear
+       type(epPos)::  p3 ! input.  "square" may be skewed
+       type(epPos)::  p4 ! input.  2 of them may be the same.
+       type(epPos)::  n  ! input. normal vector of the plane
+       type(epPos)::  p  ! input given point which is on the plane fomred by
                         !  three points p1, p2, p3, p4
 
       integer icon  ! output. 0: p is inside of the "square"
@@ -397,66 +396,66 @@ c            p31 should be 0
 
       subroutine ep3p2plane(p1, p2, p3, n, k)
       implicit none
-c        3 points to palne;
-c        get normal vector and const to represent a plane
-c        formed by a  three non-colinear points
-c
+!        3 points to palne;
+!        get normal vector and const to represent a plane
+!        formed by a  three non-colinear points
+!
 #include "ZepPos.h"
-      record /epPos/ p1  ! input. first point
-      record /epPos/ p2  ! input. second point
-      record /epPos/ p3  ! input. 3rd point.  They should not be on a line.
-      record /epPos/ n   ! output.a vector normal to the plane  formed by
+       type(epPos)::  p1  ! input. first point
+       type(epPos)::  p2  ! input. second point
+       type(epPos)::  p3  ! input. 3rd point.  They should not be on a line.
+       type(epPos)::  n   ! output.a vector normal to the plane  formed by
                          !      p1,p2,p3.. it is a unit vector (from v9.136) 
       real*8 k           ! output. const to represent the plane.
                          ! vec(n).vec(x) = k where x is any point on the plane.
 
-      record /epPos/ p2p1, p3p2
-      record /epPos/ p3p1
+       type(epPos)::  p2p1, p3p2
+       type(epPos)::  p3p1
       real(8):: norm
       call epdiff3vec(p2, p1, p2p1)
-c      call epdiff3vec(p3, p2, p3p2)
+!      call epdiff3vec(p3, p2, p3p2)
       call epdiff3vec(p3, p1, p3p1)
-c      call epvectorProd(p2p1, p3p2, n)
+!      call epvectorProd(p2p1, p3p2, n)
       call epvectorProd(p2p1, p3p1, n)
       call epscalerProd(n, n, norm)
       norm = sqrt(norm)
-      n.x = n.x/norm
-      n.y = n.y/norm
-      n.z = n.z/norm
+      n%x = n%x/norm
+      n%y = n%y/norm
+      n%z = n%z/norm
       call epscalerProd(n, p1, k)
       end
       
       subroutine epdiff3vec(p1, p2, p3)
       implicit none
 #include "ZepPos.h"
-      record /epPos/ p1  ! input.  
-      record /epPos/ p2  ! input.  
-      record /epPos/ p3  ! output p3 = p1 - p2
+       type(epPos)::  p1  ! input.  
+       type(epPos)::  p2  ! input.  
+       type(epPos)::  p3  ! output p3 = p1 - p2
 
-      p3.x = p1.x - p2.x
-      p3.y = p1.y - p2.y
-      p3.z = p1.z - p2.z
+      p3%x = p1%x - p2%x
+      p3%y = p1%y - p2%y
+      p3%z = p1%z - p2%z
       end
       subroutine epscalerProd(p1, p2, ans)
       implicit none
 #include "ZepPos.h"
-      record /epPos/ p1  ! input.  
-      record /epPos/ p2  ! input.  
+       type(epPos)::  p1  ! input.  
+       type(epPos)::  p2  ! input.  
       real*8 ans  ! output ans = p1.p2
 
-      ans = p1.x * p2.x + p1.y * p2.y +  p1.z * p2.z
+      ans = p1%x * p2%x + p1%y * p2%y +  p1%z * p2%z
       end
 
       subroutine epvectorProd(p1, p2, p3)
       implicit none
 #include "ZepPos.h"
-      record /epPos/ p1  ! input.  
-      record /epPos/ p2  ! input.  
-      record /epPos/ p3  ! output. p1 x p2
+       type(epPos)::  p1  ! input.  
+       type(epPos)::  p2  ! input.  
+       type(epPos)::  p3  ! output. p1 x p2
 
-      p3.x = p1.y*p2.z - p1.z* p2.y
-      p3.y = p1.z*p2.x - p1.x* p2.z
-      p3.z = p1.x*p2.y - p1.y* p2.x
+      p3%x = p1%y*p2%z - p1%z* p2%y
+      p3%y = p1%z*p2%x - p1%x* p2%z
+      p3%z = p1%x*p2%y - p1%y* p2%x
 
       end
       subroutine epwhichside(nm, k, p, diff)
