@@ -1,3 +1,5 @@
+!  next is to incldue MATHLOUSY 
+#include "Zcondc.h"
 !           test prog. is  in Epics/prog/Test/ (./testRange.sh)
 !       memory allocation; to save it, use single precision
       module modepRange
@@ -40,11 +42,22 @@
       real(8),parameter:: gbeta1 =0.01d0 ! 
       real(8),parameter:: gbeta2 = 2.0d0 
       real(8),parameter:: dKE = 0.1d0     ! log10 step from Ex1 to Ex2        
-      real(8),parameter:: logKE1 = log10(KE1)  ! energy step is in log step
+#if defined (MATHLOUSY)
+
+      real(8),parameter:: logKE1 = -6.d0 ! energy step is in log step
+      real(8),parameter:: logKE2 = -3.d0
+      integer,parameter:: nGBbin=
+     *    (3.01029995663981195215d-1 - (-2) )/dKE+1
+
+#else    
+
+      real(8),parameter:: logKE1 = log10(KE1) ! energy step is in log step
       real(8),parameter:: logKE2 = log10(KE2)
-      integer,parameter:: nKEbin= ( logKE2- logKE1 )/dKE + 1
       integer,parameter:: nGBbin= (log10(gbeta2)- log10(gbeta1) )/dKE+1
 
+#endif
+
+      integer,parameter:: nKEbin= ( logKE2- logKE1 )/dKE + 1
       real(prec),save:: logKEtbl(nKEbin)   ! log10(KE)
       real(prec),save:: logGBetatbl(nGBbin)  ! 
       real(prec),save,allocatable:: logGamLen(:,:)  !  gamma length(cm) (log is false)
@@ -88,7 +101,7 @@
       implicit none
 #include "Zmedia.h"
 #include "Zptcl.h"
-      record /epmedia/ media  ! input media
+       type(epmedia)::  media  ! input media
       integer,intent(in):: idx  ! media index 
       
 
@@ -102,20 +115,23 @@
 
 
       common /Zrange/ myPtcl, mymedia
-      record /ptcl/ myPtcl
-      record /epmedia/ mymedia
+       type(ptcl)::  myPtcl
+       type(epmedia)::  mymedia
       external epRangeFunc
       real(8):: epRangeFunc
       
       mymedia = media
-      
+!/////////////
+      mymedia%sh%tcut = 1.d10
+      mymedia%sh%w0 = 1.d10
+!//////////////////
       E = KE1
 !           gamma 
       do i = 1, nKEbin
 !         logKEtbl(i) = log10(E)
          logKEtbl(i) = E
          E4 = E
-         call cGetXXsec(E4, media.xcom, media.xcom.size,
+         call cGetXXsec(E4, media%xcom, media%xcom%size,
      *           7, 7, xsec, icon)
 !            xsec(7) is total atten. coef. in cm2/g. 
          logGamLen(i, idx) =  xsec(7) 
@@ -182,8 +198,8 @@
 
       do i = 1, nGBbin   
          logGBetatbl(i) = gbeta
-         E = sqrt((myPtcl.mass*gbeta)**2 + myPtcl.mass**2) 
-         Esum = E - myPtcl.mass
+         E = sqrt((myPtcl%mass*gbeta)**2 + myPtcl%mass**2) 
+         Esum = E - myPtcl%mass
 !/////////
          call kdexpIntF(epRangeFunc, 1d-6, Esum, eps,
      *        ans, error, icon)
@@ -217,7 +233,7 @@
 !//////////
 !!         write(0,*) ' range =',range
 !/////////////
-         logChgLen(i, idx) =  ans/myPtcl.mass
+         logChgLen(i, idx) =  ans/myPtcl%mass
          gbeta = gbeta * 10.d0**dKE
       enddo
 !//////////
@@ -230,14 +246,14 @@
       eps = 1.d-7
 
       do i = 1, nGBbin   
-         E = sqrt((myPtcl.mass*gbeta)**2 + myPtcl.mass**2) 
-         Esum = E - myPtcl.mass
+         E = sqrt((myPtcl%mass*gbeta)**2 + myPtcl%mass**2) 
+         Esum = E - myPtcl%mass
          call kdexpIntF(epRangeFunc, 1d-6, Esum, eps,
      *        ans, error, icon)
          if(ans > 1.) then
             eps = 1.d-4
          endif
-         logHILen(i, idx) =  ans/myPtcl.mass
+         logHILen(i, idx) =  ans/myPtcl%mass
          gbeta = gbeta * 10.d0**dKE
       enddo
 !//////////
@@ -253,18 +269,18 @@
 #include "Zcode.h"
 
       common /Zrange/ myPtcl, mymedia
-      record /ptcl/ myPtcl
-      record /epmedia/ mymedia
+       type(ptcl)::  myPtcl
+       type(epmedia)::  mymedia
 
       real(8):: epRangeFunc
       real(8),intent(in)::E !  kinetic energy GeV
 
       real(8):: dedtfull, dedt
 
-      myPtcl.fm.p(4) = E  + myPtcl.mass
-      if( myPtcl.code == kelec) then
+      myPtcl%fm%p(4) = E  + myPtcl%mass
+      if( myPtcl%code == kelec) then
          call epdedxe(mymedia, myPtcl, dedt, dedtfull)
-      elseif( myPtcl.code == kgnuc ) then
+      elseif( myPtcl%code == kgnuc ) then
          call epdedxhvy( mymedia, myPtcl, dedt, dedtfull)
       else
          call epdedxNone(mymedia, myPtcl, dedt, dedtfull)
@@ -281,8 +297,8 @@
 #include "Zptcl.h"        
 #include "Zcode.h"        
       integer,intent(in):: idx ! media index
-      record /epmedia/ media  ! input media corresponding to idx
-      record /ptcl/ aPtcl   ! input.  charged ptcl or photon
+       type(epmedia)::  media  ! input media corresponding to idx
+       type(ptcl)::  aPtcl   ! input.  charged ptcl or photon
 
       real(8),intent(out):: grmlen  !  length in g/cm2  range of
                            ! this charged ptcl.
@@ -296,8 +312,8 @@
 
 
 
-      if( aPtcl.code  == kelec ) then
-         Ek = aPtcl.fm.p(4) - aPtcl.mass
+      if( aPtcl%code  == kelec ) then
+         Ek = aPtcl%fm%p(4) - aPtcl%mass
 !               electron
          if( Ek < KE1 ) then
             grmlen = logEleLen(1,idx) / 10.  ! normally absobed 
@@ -315,8 +331,8 @@
             grmlen = grmlenS
          endif
 
-      elseif( aPtcl.code == kphoton ) then
-         Ek = aPtcl.fm.p(4)
+      elseif( aPtcl%code == kphoton ) then
+         Ek = aPtcl%fm%p(4)
 !           photon
          if( Ek < KE1 ) then
             grmlen = logGamLen(1,idx) * 10.  ! grmlen still 1/attenL so not "/10"
@@ -337,9 +353,9 @@
          grmlen = attenF/ grmlen    ! AttenF x attenuation length  in g/cm2
 
 
-      elseif( aPtcl.charge /= 0  .and. aPtcl.code /= kgnuc ) then
+      elseif( aPtcl%charge /= 0  .and. aPtcl%code /= kgnuc ) then
 !      mu,pi,p
-         g =  aPtcl.fm.p(4)/aPtcl.mass
+         g =  aPtcl%fm%p(4)/aPtcl%mass
          gb = sqrt(g**2 - 1.0d0)
          if( gb < gbeta1 ) then
             grmlen = logChgLen(1,idx) / 10.  ! normally absobed instantly
@@ -351,12 +367,12 @@
      *             3,       gb, grmlenS, error)
             grmlen = grmlenS
          endif
-         grmlen = grmlen/aPtcl.charge**2
-         grmlen = grmlen * aPtcl.mass
+         grmlen = grmlen/aPtcl%charge**2
+         grmlen = grmlen * aPtcl%mass
 
-      elseif( aPtcl.code == kgnuc ) then
+      elseif( aPtcl%code == kgnuc ) then
 !            heavy icon ; use scalig by using He
-         g =  aPtcl.fm.p(4)/aPtcl.mass
+         g =  aPtcl%fm%p(4)/aPtcl%mass
          gb = sqrt(g**2 - 1.0d0)
          if( gb < gbeta1 ) then
             grmlen = logHILen(1,idx) / 10.  ! normally absobed instantly
@@ -368,13 +384,13 @@
      *             3,       gb, grmlenS, error)
             grmlen = grmlenS
          endif
-         grmlen = grmlen/(aPtcl.charge/2.0)**2
-         grmlen = grmlen * aPtcl.mass
+         grmlen = grmlen/(aPtcl%charge/2.0)**2
+         grmlen = grmlen * aPtcl%mass
       else
          ! basically should not come here
          grmlen = 1000.
       endif
-      cmlen = grmlen /(media.rho*media.rhoc)
+      cmlen = grmlen /(media%rho*media%rhoc)
       end
 
 
@@ -388,8 +404,8 @@
 #include "Zptcl.h"        
 #include "Zcode.h"        
       integer,intent(in):: idx ! media index
-      record /epmedia/ media  ! input media corresponding to idx
-      record /ptcl/ aPtcl   ! input.  charged ptcl or photon
+       type(epmedia)::  media  ! input media corresponding to idx
+       type(ptcl)::  aPtcl   ! input.  charged ptcl or photon
 
       real(8),intent(in):: cmlen   ! range length in cm
       real(8),intent(out):: Ek   ! kinetic energy (GeV) of the
@@ -401,8 +417,8 @@
       real(8):: g
 
       
-      if( aPtcl.code == kphoton ) then
-         grmlen = cmlen * media.rho*media.rhoc
+      if( aPtcl%code == kphoton ) then
+         grmlen = cmlen * media%rho*media%rhoc
 !           photon
          if( grmlen < logGamLen(1,idx)  ) then
             Ek = KE1
@@ -417,7 +433,7 @@
       else
          write(0,*)
      *         ' at present epRange2Ek is not usable for'
-         write(0,*) ' particle code=',aPtcl.code
+         write(0,*) ' particle code=',aPtcl%code
          stop
       endif
       end
