@@ -275,7 +275,7 @@
       subroutine arprmm(vvalue, c)
       implicit none
       character*(*) vvalue
-      complex*16 c
+      complex(8):: c
       read( vvalue, *)   c, c
       end
 !     ************************ integer data
@@ -330,7 +330,7 @@
       implicit none
       integer io
       character*(*) vname
-      complex*16  c
+      complex(8)::  c
       write(io,  *) ' ', vname,' ', c,' /'
       end
       subroutine awprmi(io, vname, i)
