@@ -2,6 +2,7 @@
       use modV1ry
       use SampMolReducedA
       use modMCSparam
+      use modDirecPair,only: DirecPair, BareTarget, AdjFac
       implicit none
 #include  "ZepTrackp.h"
 #include  "ZepManager.h"
@@ -113,6 +114,14 @@
                   else
                      call arprmi(vvalue, Moliere)
                   endif
+                  !!!!!!!!!!Next 34 are for the direct pair creation
+               elseif( vname == 'DirecPair' ) then
+                  call arprml(vvalue, DirecPair)
+               elseif( vname == 'BareTarget' ) then
+                  call arprml(vvalue, BareTarget) 
+               elseif( vname == 'AdjFac' ) then
+                  call arprmr(vvalue, AdjFac ) 
+                  !!!!!!!!!
                elseif( vname == 'MCSmodel' ) then
                   call arprmc(vvalue, MCSmodel)
                elseif( vname == 'MCSdir' ) then
@@ -135,7 +144,7 @@
 !                     write(0,*) ' too many MCSyRange'
 !                     stop
 !                  endif
-             elseif( vname == 'MCSzRange' ) then
+               elseif( vname == 'MCSzRange' ) then
                   if(MCSzCond < MCSxyzCondmx) then
                      MCSzCond = MCSzCond+1
                      call arprmm(vvalue, MCSzRange(MCSzCond))
